# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class SyncJobRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'target_id': 'str',
        'item_ids': 'list[str]',
        'category': 'SyncCategory',
        'parent_id': 'str',
        'quality': 'str',
        'profile': 'str',
        'container': 'str',
        'video_codec': 'str',
        'audio_codec': 'str',
        'name': 'str',
        'user_id': 'str',
        'unwatched_only': 'bool',
        'sync_new_content': 'bool',
        'item_limit': 'int',
        'bitrate': 'int',
        'downloaded': 'bool'
    }

    attribute_map = {
        'target_id': 'TargetId',
        'item_ids': 'ItemIds',
        'category': 'Category',
        'parent_id': 'ParentId',
        'quality': 'Quality',
        'profile': 'Profile',
        'container': 'Container',
        'video_codec': 'VideoCodec',
        'audio_codec': 'AudioCodec',
        'name': 'Name',
        'user_id': 'UserId',
        'unwatched_only': 'UnwatchedOnly',
        'sync_new_content': 'SyncNewContent',
        'item_limit': 'ItemLimit',
        'bitrate': 'Bitrate',
        'downloaded': 'Downloaded'
    }

    def __init__(self, target_id=None, item_ids=None, category=None, parent_id=None, quality=None, profile=None, container=None, video_codec=None, audio_codec=None, name=None, user_id=None, unwatched_only=None, sync_new_content=None, item_limit=None, bitrate=None, downloaded=None):  # noqa: E501
        """SyncJobRequest - a model defined in Swagger"""  # noqa: E501
        self._target_id = None
        self._item_ids = None
        self._category = None
        self._parent_id = None
        self._quality = None
        self._profile = None
        self._container = None
        self._video_codec = None
        self._audio_codec = None
        self._name = None
        self._user_id = None
        self._unwatched_only = None
        self._sync_new_content = None
        self._item_limit = None
        self._bitrate = None
        self._downloaded = None
        self.discriminator = None
        if target_id is not None:
            self.target_id = target_id
        if item_ids is not None:
            self.item_ids = item_ids
        if category is not None:
            self.category = category
        if parent_id is not None:
            self.parent_id = parent_id
        if quality is not None:
            self.quality = quality
        if profile is not None:
            self.profile = profile
        if container is not None:
            self.container = container
        if video_codec is not None:
            self.video_codec = video_codec
        if audio_codec is not None:
            self.audio_codec = audio_codec
        if name is not None:
            self.name = name
        if user_id is not None:
            self.user_id = user_id
        if unwatched_only is not None:
            self.unwatched_only = unwatched_only
        if sync_new_content is not None:
            self.sync_new_content = sync_new_content
        if item_limit is not None:
            self.item_limit = item_limit
        if bitrate is not None:
            self.bitrate = bitrate
        if downloaded is not None:
            self.downloaded = downloaded

    @property
    def target_id(self):
        """Gets the target_id of this SyncJobRequest.  # noqa: E501


        :return: The target_id of this SyncJobRequest.  # noqa: E501
        :rtype: str
        """
        return self._target_id

    @target_id.setter
    def target_id(self, target_id):
        """Sets the target_id of this SyncJobRequest.


        :param target_id: The target_id of this SyncJobRequest.  # noqa: E501
        :type: str
        """

        self._target_id = target_id

    @property
    def item_ids(self):
        """Gets the item_ids of this SyncJobRequest.  # noqa: E501


        :return: The item_ids of this SyncJobRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._item_ids

    @item_ids.setter
    def item_ids(self, item_ids):
        """Sets the item_ids of this SyncJobRequest.


        :param item_ids: The item_ids of this SyncJobRequest.  # noqa: E501
        :type: list[str]
        """

        self._item_ids = item_ids

    @property
    def category(self):
        """Gets the category of this SyncJobRequest.  # noqa: E501


        :return: The category of this SyncJobRequest.  # noqa: E501
        :rtype: SyncCategory
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this SyncJobRequest.


        :param category: The category of this SyncJobRequest.  # noqa: E501
        :type: SyncCategory
        """

        self._category = category

    @property
    def parent_id(self):
        """Gets the parent_id of this SyncJobRequest.  # noqa: E501


        :return: The parent_id of this SyncJobRequest.  # noqa: E501
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """Sets the parent_id of this SyncJobRequest.


        :param parent_id: The parent_id of this SyncJobRequest.  # noqa: E501
        :type: str
        """

        self._parent_id = parent_id

    @property
    def quality(self):
        """Gets the quality of this SyncJobRequest.  # noqa: E501


        :return: The quality of this SyncJobRequest.  # noqa: E501
        :rtype: str
        """
        return self._quality

    @quality.setter
    def quality(self, quality):
        """Sets the quality of this SyncJobRequest.


        :param quality: The quality of this SyncJobRequest.  # noqa: E501
        :type: str
        """

        self._quality = quality

    @property
    def profile(self):
        """Gets the profile of this SyncJobRequest.  # noqa: E501


        :return: The profile of this SyncJobRequest.  # noqa: E501
        :rtype: str
        """
        return self._profile

    @profile.setter
    def profile(self, profile):
        """Sets the profile of this SyncJobRequest.


        :param profile: The profile of this SyncJobRequest.  # noqa: E501
        :type: str
        """

        self._profile = profile

    @property
    def container(self):
        """Gets the container of this SyncJobRequest.  # noqa: E501


        :return: The container of this SyncJobRequest.  # noqa: E501
        :rtype: str
        """
        return self._container

    @container.setter
    def container(self, container):
        """Sets the container of this SyncJobRequest.


        :param container: The container of this SyncJobRequest.  # noqa: E501
        :type: str
        """

        self._container = container

    @property
    def video_codec(self):
        """Gets the video_codec of this SyncJobRequest.  # noqa: E501


        :return: The video_codec of this SyncJobRequest.  # noqa: E501
        :rtype: str
        """
        return self._video_codec

    @video_codec.setter
    def video_codec(self, video_codec):
        """Sets the video_codec of this SyncJobRequest.


        :param video_codec: The video_codec of this SyncJobRequest.  # noqa: E501
        :type: str
        """

        self._video_codec = video_codec

    @property
    def audio_codec(self):
        """Gets the audio_codec of this SyncJobRequest.  # noqa: E501


        :return: The audio_codec of this SyncJobRequest.  # noqa: E501
        :rtype: str
        """
        return self._audio_codec

    @audio_codec.setter
    def audio_codec(self, audio_codec):
        """Sets the audio_codec of this SyncJobRequest.


        :param audio_codec: The audio_codec of this SyncJobRequest.  # noqa: E501
        :type: str
        """

        self._audio_codec = audio_codec

    @property
    def name(self):
        """Gets the name of this SyncJobRequest.  # noqa: E501


        :return: The name of this SyncJobRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SyncJobRequest.


        :param name: The name of this SyncJobRequest.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def user_id(self):
        """Gets the user_id of this SyncJobRequest.  # noqa: E501


        :return: The user_id of this SyncJobRequest.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this SyncJobRequest.


        :param user_id: The user_id of this SyncJobRequest.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def unwatched_only(self):
        """Gets the unwatched_only of this SyncJobRequest.  # noqa: E501


        :return: The unwatched_only of this SyncJobRequest.  # noqa: E501
        :rtype: bool
        """
        return self._unwatched_only

    @unwatched_only.setter
    def unwatched_only(self, unwatched_only):
        """Sets the unwatched_only of this SyncJobRequest.


        :param unwatched_only: The unwatched_only of this SyncJobRequest.  # noqa: E501
        :type: bool
        """

        self._unwatched_only = unwatched_only

    @property
    def sync_new_content(self):
        """Gets the sync_new_content of this SyncJobRequest.  # noqa: E501


        :return: The sync_new_content of this SyncJobRequest.  # noqa: E501
        :rtype: bool
        """
        return self._sync_new_content

    @sync_new_content.setter
    def sync_new_content(self, sync_new_content):
        """Sets the sync_new_content of this SyncJobRequest.


        :param sync_new_content: The sync_new_content of this SyncJobRequest.  # noqa: E501
        :type: bool
        """

        self._sync_new_content = sync_new_content

    @property
    def item_limit(self):
        """Gets the item_limit of this SyncJobRequest.  # noqa: E501


        :return: The item_limit of this SyncJobRequest.  # noqa: E501
        :rtype: int
        """
        return self._item_limit

    @item_limit.setter
    def item_limit(self, item_limit):
        """Sets the item_limit of this SyncJobRequest.


        :param item_limit: The item_limit of this SyncJobRequest.  # noqa: E501
        :type: int
        """

        self._item_limit = item_limit

    @property
    def bitrate(self):
        """Gets the bitrate of this SyncJobRequest.  # noqa: E501


        :return: The bitrate of this SyncJobRequest.  # noqa: E501
        :rtype: int
        """
        return self._bitrate

    @bitrate.setter
    def bitrate(self, bitrate):
        """Sets the bitrate of this SyncJobRequest.


        :param bitrate: The bitrate of this SyncJobRequest.  # noqa: E501
        :type: int
        """

        self._bitrate = bitrate

    @property
    def downloaded(self):
        """Gets the downloaded of this SyncJobRequest.  # noqa: E501


        :return: The downloaded of this SyncJobRequest.  # noqa: E501
        :rtype: bool
        """
        return self._downloaded

    @downloaded.setter
    def downloaded(self, downloaded):
        """Sets the downloaded of this SyncJobRequest.


        :param downloaded: The downloaded of this SyncJobRequest.  # noqa: E501
        :type: bool
        """

        self._downloaded = downloaded

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SyncJobRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SyncJobRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class MetadataEditorInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'parental_rating_options': 'list[ParentalRating]',
        'countries': 'list[GlobalizationCountryInfo]',
        'cultures': 'list[GlobalizationCultureDto]',
        'external_id_infos': 'list[ExternalIdInfo]'
    }

    attribute_map = {
        'parental_rating_options': 'ParentalRatingOptions',
        'countries': 'Countries',
        'cultures': 'Cultures',
        'external_id_infos': 'ExternalIdInfos'
    }

    def __init__(self, parental_rating_options=None, countries=None, cultures=None, external_id_infos=None):  # noqa: E501
        """MetadataEditorInfo - a model defined in Swagger"""  # noqa: E501
        self._parental_rating_options = None
        self._countries = None
        self._cultures = None
        self._external_id_infos = None
        self.discriminator = None
        if parental_rating_options is not None:
            self.parental_rating_options = parental_rating_options
        if countries is not None:
            self.countries = countries
        if cultures is not None:
            self.cultures = cultures
        if external_id_infos is not None:
            self.external_id_infos = external_id_infos

    @property
    def parental_rating_options(self):
        """Gets the parental_rating_options of this MetadataEditorInfo.  # noqa: E501


        :return: The parental_rating_options of this MetadataEditorInfo.  # noqa: E501
        :rtype: list[ParentalRating]
        """
        return self._parental_rating_options

    @parental_rating_options.setter
    def parental_rating_options(self, parental_rating_options):
        """Sets the parental_rating_options of this MetadataEditorInfo.


        :param parental_rating_options: The parental_rating_options of this MetadataEditorInfo.  # noqa: E501
        :type: list[ParentalRating]
        """

        self._parental_rating_options = parental_rating_options

    @property
    def countries(self):
        """Gets the countries of this MetadataEditorInfo.  # noqa: E501


        :return: The countries of this MetadataEditorInfo.  # noqa: E501
        :rtype: list[GlobalizationCountryInfo]
        """
        return self._countries

    @countries.setter
    def countries(self, countries):
        """Sets the countries of this MetadataEditorInfo.


        :param countries: The countries of this MetadataEditorInfo.  # noqa: E501
        :type: list[GlobalizationCountryInfo]
        """

        self._countries = countries

    @property
    def cultures(self):
        """Gets the cultures of this MetadataEditorInfo.  # noqa: E501


        :return: The cultures of this MetadataEditorInfo.  # noqa: E501
        :rtype: list[GlobalizationCultureDto]
        """
        return self._cultures

    @cultures.setter
    def cultures(self, cultures):
        """Sets the cultures of this MetadataEditorInfo.


        :param cultures: The cultures of this MetadataEditorInfo.  # noqa: E501
        :type: list[GlobalizationCultureDto]
        """

        self._cultures = cultures

    @property
    def external_id_infos(self):
        """Gets the external_id_infos of this MetadataEditorInfo.  # noqa: E501


        :return: The external_id_infos of this MetadataEditorInfo.  # noqa: E501
        :rtype: list[ExternalIdInfo]
        """
        return self._external_id_infos

    @external_id_infos.setter
    def external_id_infos(self, external_id_infos):
        """Sets the external_id_infos of this MetadataEditorInfo.


        :param external_id_infos: The external_id_infos of this MetadataEditorInfo.  # noqa: E501
        :type: list[ExternalIdInfo]
        """

        self._external_id_infos = external_id_infos

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MetadataEditorInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MetadataEditorInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class ItemCounts(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'movie_count': 'int',
        'series_count': 'int',
        'episode_count': 'int',
        'game_count': 'int',
        'artist_count': 'int',
        'program_count': 'int',
        'game_system_count': 'int',
        'trailer_count': 'int',
        'song_count': 'int',
        'album_count': 'int',
        'music_video_count': 'int',
        'box_set_count': 'int',
        'book_count': 'int',
        'item_count': 'int'
    }

    attribute_map = {
        'movie_count': 'MovieCount',
        'series_count': 'SeriesCount',
        'episode_count': 'EpisodeCount',
        'game_count': 'GameCount',
        'artist_count': 'ArtistCount',
        'program_count': 'ProgramCount',
        'game_system_count': 'GameSystemCount',
        'trailer_count': 'TrailerCount',
        'song_count': 'SongCount',
        'album_count': 'AlbumCount',
        'music_video_count': 'MusicVideoCount',
        'box_set_count': 'BoxSetCount',
        'book_count': 'BookCount',
        'item_count': 'ItemCount'
    }

    def __init__(self, movie_count=None, series_count=None, episode_count=None, game_count=None, artist_count=None, program_count=None, game_system_count=None, trailer_count=None, song_count=None, album_count=None, music_video_count=None, box_set_count=None, book_count=None, item_count=None):  # noqa: E501
        """ItemCounts - a model defined in Swagger"""  # noqa: E501
        self._movie_count = None
        self._series_count = None
        self._episode_count = None
        self._game_count = None
        self._artist_count = None
        self._program_count = None
        self._game_system_count = None
        self._trailer_count = None
        self._song_count = None
        self._album_count = None
        self._music_video_count = None
        self._box_set_count = None
        self._book_count = None
        self._item_count = None
        self.discriminator = None
        if movie_count is not None:
            self.movie_count = movie_count
        if series_count is not None:
            self.series_count = series_count
        if episode_count is not None:
            self.episode_count = episode_count
        if game_count is not None:
            self.game_count = game_count
        if artist_count is not None:
            self.artist_count = artist_count
        if program_count is not None:
            self.program_count = program_count
        if game_system_count is not None:
            self.game_system_count = game_system_count
        if trailer_count is not None:
            self.trailer_count = trailer_count
        if song_count is not None:
            self.song_count = song_count
        if album_count is not None:
            self.album_count = album_count
        if music_video_count is not None:
            self.music_video_count = music_video_count
        if box_set_count is not None:
            self.box_set_count = box_set_count
        if book_count is not None:
            self.book_count = book_count
        if item_count is not None:
            self.item_count = item_count

    @property
    def movie_count(self):
        """Gets the movie_count of this ItemCounts.  # noqa: E501

        The movie count.  # noqa: E501

        :return: The movie_count of this ItemCounts.  # noqa: E501
        :rtype: int
        """
        return self._movie_count

    @movie_count.setter
    def movie_count(self, movie_count):
        """Sets the movie_count of this ItemCounts.

        The movie count.  # noqa: E501

        :param movie_count: The movie_count of this ItemCounts.  # noqa: E501
        :type: int
        """

        self._movie_count = movie_count

    @property
    def series_count(self):
        """Gets the series_count of this ItemCounts.  # noqa: E501

        The series count.  # noqa: E501

        :return: The series_count of this ItemCounts.  # noqa: E501
        :rtype: int
        """
        return self._series_count

    @series_count.setter
    def series_count(self, series_count):
        """Sets the series_count of this ItemCounts.

        The series count.  # noqa: E501

        :param series_count: The series_count of this ItemCounts.  # noqa: E501
        :type: int
        """

        self._series_count = series_count

    @property
    def episode_count(self):
        """Gets the episode_count of this ItemCounts.  # noqa: E501

        The episode count.  # noqa: E501

        :return: The episode_count of this ItemCounts.  # noqa: E501
        :rtype: int
        """
        return self._episode_count

    @episode_count.setter
    def episode_count(self, episode_count):
        """Sets the episode_count of this ItemCounts.

        The episode count.  # noqa: E501

        :param episode_count: The episode_count of this ItemCounts.  # noqa: E501
        :type: int
        """

        self._episode_count = episode_count

    @property
    def game_count(self):
        """Gets the game_count of this ItemCounts.  # noqa: E501

        The game count.  # noqa: E501

        :return: The game_count of this ItemCounts.  # noqa: E501
        :rtype: int
        """
        return self._game_count

    @game_count.setter
    def game_count(self, game_count):
        """Sets the game_count of this ItemCounts.

        The game count.  # noqa: E501

        :param game_count: The game_count of this ItemCounts.  # noqa: E501
        :type: int
        """

        self._game_count = game_count

    @property
    def artist_count(self):
        """Gets the artist_count of this ItemCounts.  # noqa: E501


        :return: The artist_count of this ItemCounts.  # noqa: E501
        :rtype: int
        """
        return self._artist_count

    @artist_count.setter
    def artist_count(self, artist_count):
        """Sets the artist_count of this ItemCounts.


        :param artist_count: The artist_count of this ItemCounts.  # noqa: E501
        :type: int
        """

        self._artist_count = artist_count

    @property
    def program_count(self):
        """Gets the program_count of this ItemCounts.  # noqa: E501


        :return: The program_count of this ItemCounts.  # noqa: E501
        :rtype: int
        """
        return self._program_count

    @program_count.setter
    def program_count(self, program_count):
        """Sets the program_count of this ItemCounts.


        :param program_count: The program_count of this ItemCounts.  # noqa: E501
        :type: int
        """

        self._program_count = program_count

    @property
    def game_system_count(self):
        """Gets the game_system_count of this ItemCounts.  # noqa: E501

        The game system count.  # noqa: E501

        :return: The game_system_count of this ItemCounts.  # noqa: E501
        :rtype: int
        """
        return self._game_system_count

    @game_system_count.setter
    def game_system_count(self, game_system_count):
        """Sets the game_system_count of this ItemCounts.

        The game system count.  # noqa: E501

        :param game_system_count: The game_system_count of this ItemCounts.  # noqa: E501
        :type: int
        """

        self._game_system_count = game_system_count

    @property
    def trailer_count(self):
        """Gets the trailer_count of this ItemCounts.  # noqa: E501

        The trailer count.  # noqa: E501

        :return: The trailer_count of this ItemCounts.  # noqa: E501
        :rtype: int
        """
        return self._trailer_count

    @trailer_count.setter
    def trailer_count(self, trailer_count):
        """Sets the trailer_count of this ItemCounts.

        The trailer count.  # noqa: E501

        :param trailer_count: The trailer_count of this ItemCounts.  # noqa: E501
        :type: int
        """

        self._trailer_count = trailer_count

    @property
    def song_count(self):
        """Gets the song_count of this ItemCounts.  # noqa: E501

        The song count.  # noqa: E501

        :return: The song_count of this ItemCounts.  # noqa: E501
        :rtype: int
        """
        return self._song_count

    @song_count.setter
    def song_count(self, song_count):
        """Sets the song_count of this ItemCounts.

        The song count.  # noqa: E501

        :param song_count: The song_count of this ItemCounts.  # noqa: E501
        :type: int
        """

        self._song_count = song_count

    @property
    def album_count(self):
        """Gets the album_count of this ItemCounts.  # noqa: E501

        The album count.  # noqa: E501

        :return: The album_count of this ItemCounts.  # noqa: E501
        :rtype: int
        """
        return self._album_count

    @album_count.setter
    def album_count(self, album_count):
        """Sets the album_count of this ItemCounts.

        The album count.  # noqa: E501

        :param album_count: The album_count of this ItemCounts.  # noqa: E501
        :type: int
        """

        self._album_count = album_count

    @property
    def music_video_count(self):
        """Gets the music_video_count of this ItemCounts.  # noqa: E501

        The music video count.  # noqa: E501

        :return: The music_video_count of this ItemCounts.  # noqa: E501
        :rtype: int
        """
        return self._music_video_count

    @music_video_count.setter
    def music_video_count(self, music_video_count):
        """Sets the music_video_count of this ItemCounts.

        The music video count.  # noqa: E501

        :param music_video_count: The music_video_count of this ItemCounts.  # noqa: E501
        :type: int
        """

        self._music_video_count = music_video_count

    @property
    def box_set_count(self):
        """Gets the box_set_count of this ItemCounts.  # noqa: E501

        The box set count.  # noqa: E501

        :return: The box_set_count of this ItemCounts.  # noqa: E501
        :rtype: int
        """
        return self._box_set_count

    @box_set_count.setter
    def box_set_count(self, box_set_count):
        """Sets the box_set_count of this ItemCounts.

        The box set count.  # noqa: E501

        :param box_set_count: The box_set_count of this ItemCounts.  # noqa: E501
        :type: int
        """

        self._box_set_count = box_set_count

    @property
    def book_count(self):
        """Gets the book_count of this ItemCounts.  # noqa: E501

        The book count.  # noqa: E501

        :return: The book_count of this ItemCounts.  # noqa: E501
        :rtype: int
        """
        return self._book_count

    @book_count.setter
    def book_count(self, book_count):
        """Sets the book_count of this ItemCounts.

        The book count.  # noqa: E501

        :param book_count: The book_count of this ItemCounts.  # noqa: E501
        :type: int
        """

        self._book_count = book_count

    @property
    def item_count(self):
        """Gets the item_count of this ItemCounts.  # noqa: E501


        :return: The item_count of this ItemCounts.  # noqa: E501
        :rtype: int
        """
        return self._item_count

    @item_count.setter
    def item_count(self, item_count):
        """Sets the item_count of this ItemCounts.


        :param item_count: The item_count of this ItemCounts.  # noqa: E501
        :type: int
        """

        self._item_count = item_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ItemCounts, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ItemCounts):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class BrandingBrandingOptions(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'login_disclaimer': 'str',
        'custom_css': 'str'
    }

    attribute_map = {
        'login_disclaimer': 'LoginDisclaimer',
        'custom_css': 'CustomCss'
    }

    def __init__(self, login_disclaimer=None, custom_css=None):  # noqa: E501
        """BrandingBrandingOptions - a model defined in Swagger"""  # noqa: E501
        self._login_disclaimer = None
        self._custom_css = None
        self.discriminator = None
        if login_disclaimer is not None:
            self.login_disclaimer = login_disclaimer
        if custom_css is not None:
            self.custom_css = custom_css

    @property
    def login_disclaimer(self):
        """Gets the login_disclaimer of this BrandingBrandingOptions.  # noqa: E501

        The login disclaimer.  # noqa: E501

        :return: The login_disclaimer of this BrandingBrandingOptions.  # noqa: E501
        :rtype: str
        """
        return self._login_disclaimer

    @login_disclaimer.setter
    def login_disclaimer(self, login_disclaimer):
        """Sets the login_disclaimer of this BrandingBrandingOptions.

        The login disclaimer.  # noqa: E501

        :param login_disclaimer: The login_disclaimer of this BrandingBrandingOptions.  # noqa: E501
        :type: str
        """

        self._login_disclaimer = login_disclaimer

    @property
    def custom_css(self):
        """Gets the custom_css of this BrandingBrandingOptions.  # noqa: E501

        The custom CSS.  # noqa: E501

        :return: The custom_css of this BrandingBrandingOptions.  # noqa: E501
        :rtype: str
        """
        return self._custom_css

    @custom_css.setter
    def custom_css(self, custom_css):
        """Sets the custom_css of this BrandingBrandingOptions.

        The custom CSS.  # noqa: E501

        :param custom_css: The custom_css of this BrandingBrandingOptions.  # noqa: E501
        :type: str
        """

        self._custom_css = custom_css

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BrandingBrandingOptions, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BrandingBrandingOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class PlaybackInfoRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'user_id': 'str',
        'max_streaming_bitrate': 'int',
        'start_time_ticks': 'int',
        'audio_stream_index': 'int',
        'subtitle_stream_index': 'int',
        'max_audio_channels': 'int',
        'media_source_id': 'str',
        'live_stream_id': 'str',
        'device_profile': 'DeviceProfile',
        'enable_direct_play': 'bool',
        'enable_direct_stream': 'bool',
        'enable_transcoding': 'bool',
        'allow_interlaced_video_stream_copy': 'bool',
        'allow_video_stream_copy': 'bool',
        'allow_audio_stream_copy': 'bool',
        'is_playback': 'bool',
        'auto_open_live_stream': 'bool',
        'current_play_session_id': 'str'
    }

    attribute_map = {
        'id': 'Id',
        'user_id': 'UserId',
        'max_streaming_bitrate': 'MaxStreamingBitrate',
        'start_time_ticks': 'StartTimeTicks',
        'audio_stream_index': 'AudioStreamIndex',
        'subtitle_stream_index': 'SubtitleStreamIndex',
        'max_audio_channels': 'MaxAudioChannels',
        'media_source_id': 'MediaSourceId',
        'live_stream_id': 'LiveStreamId',
        'device_profile': 'DeviceProfile',
        'enable_direct_play': 'EnableDirectPlay',
        'enable_direct_stream': 'EnableDirectStream',
        'enable_transcoding': 'EnableTranscoding',
        'allow_interlaced_video_stream_copy': 'AllowInterlacedVideoStreamCopy',
        'allow_video_stream_copy': 'AllowVideoStreamCopy',
        'allow_audio_stream_copy': 'AllowAudioStreamCopy',
        'is_playback': 'IsPlayback',
        'auto_open_live_stream': 'AutoOpenLiveStream',
        'current_play_session_id': 'CurrentPlaySessionId'
    }

    def __init__(self, id=None, user_id=None, max_streaming_bitrate=None, start_time_ticks=None, audio_stream_index=None, subtitle_stream_index=None, max_audio_channels=None, media_source_id=None, live_stream_id=None, device_profile=None, enable_direct_play=None, enable_direct_stream=None, enable_transcoding=None, allow_interlaced_video_stream_copy=None, allow_video_stream_copy=None, allow_audio_stream_copy=None, is_playback=None, auto_open_live_stream=None, current_play_session_id=None):  # noqa: E501
        """PlaybackInfoRequest - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._user_id = None
        self._max_streaming_bitrate = None
        self._start_time_ticks = None
        self._audio_stream_index = None
        self._subtitle_stream_index = None
        self._max_audio_channels = None
        self._media_source_id = None
        self._live_stream_id = None
        self._device_profile = None
        self._enable_direct_play = None
        self._enable_direct_stream = None
        self._enable_transcoding = None
        self._allow_interlaced_video_stream_copy = None
        self._allow_video_stream_copy = None
        self._allow_audio_stream_copy = None
        self._is_playback = None
        self._auto_open_live_stream = None
        self._current_play_session_id = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if user_id is not None:
            self.user_id = user_id
        if max_streaming_bitrate is not None:
            self.max_streaming_bitrate = max_streaming_bitrate
        if start_time_ticks is not None:
            self.start_time_ticks = start_time_ticks
        if audio_stream_index is not None:
            self.audio_stream_index = audio_stream_index
        if subtitle_stream_index is not None:
            self.subtitle_stream_index = subtitle_stream_index
        if max_audio_channels is not None:
            self.max_audio_channels = max_audio_channels
        if media_source_id is not None:
            self.media_source_id = media_source_id
        if live_stream_id is not None:
            self.live_stream_id = live_stream_id
        if device_profile is not None:
            self.device_profile = device_profile
        if enable_direct_play is not None:
            self.enable_direct_play = enable_direct_play
        if enable_direct_stream is not None:
            self.enable_direct_stream = enable_direct_stream
        if enable_transcoding is not None:
            self.enable_transcoding = enable_transcoding
        if allow_interlaced_video_stream_copy is not None:
            self.allow_interlaced_video_stream_copy = allow_interlaced_video_stream_copy
        if allow_video_stream_copy is not None:
            self.allow_video_stream_copy = allow_video_stream_copy
        if allow_audio_stream_copy is not None:
            self.allow_audio_stream_copy = allow_audio_stream_copy
        if is_playback is not None:
            self.is_playback = is_playback
        if auto_open_live_stream is not None:
            self.auto_open_live_stream = auto_open_live_stream
        if current_play_session_id is not None:
            self.current_play_session_id = current_play_session_id

    @property
    def id(self):
        """Gets the id of this PlaybackInfoRequest.  # noqa: E501


        :return: The id of this PlaybackInfoRequest.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PlaybackInfoRequest.


        :param id: The id of this PlaybackInfoRequest.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this PlaybackInfoRequest.  # noqa: E501


        :return: The user_id of this PlaybackInfoRequest.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this PlaybackInfoRequest.


        :param user_id: The user_id of this PlaybackInfoRequest.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def max_streaming_bitrate(self):
        """Gets the max_streaming_bitrate of this PlaybackInfoRequest.  # noqa: E501


        :return: The max_streaming_bitrate of this PlaybackInfoRequest.  # noqa: E501
        :rtype: int
        """
        return self._max_streaming_bitrate

    @max_streaming_bitrate.setter
    def max_streaming_bitrate(self, max_streaming_bitrate):
        """Sets the max_streaming_bitrate of this PlaybackInfoRequest.


        :param max_streaming_bitrate: The max_streaming_bitrate of this PlaybackInfoRequest.  # noqa: E501
        :type: int
        """

        self._max_streaming_bitrate = max_streaming_bitrate

    @property
    def start_time_ticks(self):
        """Gets the start_time_ticks of this PlaybackInfoRequest.  # noqa: E501


        :return: The start_time_ticks of this PlaybackInfoRequest.  # noqa: E501
        :rtype: int
        """
        return self._start_time_ticks

    @start_time_ticks.setter
    def start_time_ticks(self, start_time_ticks):
        """Sets the start_time_ticks of this PlaybackInfoRequest.


        :param start_time_ticks: The start_time_ticks of this PlaybackInfoRequest.  # noqa: E501
        :type: int
        """

        self._start_time_ticks = start_time_ticks

    @property
    def audio_stream_index(self):
        """Gets the audio_stream_index of this PlaybackInfoRequest.  # noqa: E501


        :return: The audio_stream_index of this PlaybackInfoRequest.  # noqa: E501
        :rtype: int
        """
        return self._audio_stream_index

    @audio_stream_index.setter
    def audio_stream_index(self, audio_stream_index):
        """Sets the audio_stream_index of this PlaybackInfoRequest.


        :param audio_stream_index: The audio_stream_index of this PlaybackInfoRequest.  # noqa: E501
        :type: int
        """

        self._audio_stream_index = audio_stream_index

    @property
    def subtitle_stream_index(self):
        """Gets the subtitle_stream_index of this PlaybackInfoRequest.  # noqa: E501


        :return: The subtitle_stream_index of this PlaybackInfoRequest.  # noqa: E501
        :rtype: int
        """
        return self._subtitle_stream_index

    @subtitle_stream_index.setter
    def subtitle_stream_index(self, subtitle_stream_index):
        """Sets the subtitle_stream_index of this PlaybackInfoRequest.


        :param subtitle_stream_index: The subtitle_stream_index of this PlaybackInfoRequest.  # noqa: E501
        :type: int
        """

        self._subtitle_stream_index = subtitle_stream_index

    @property
    def max_audio_channels(self):
        """Gets the max_audio_channels of this PlaybackInfoRequest.  # noqa: E501


        :return: The max_audio_channels of this PlaybackInfoRequest.  # noqa: E501
        :rtype: int
        """
        return self._max_audio_channels

    @max_audio_channels.setter
    def max_audio_channels(self, max_audio_channels):
        """Sets the max_audio_channels of this PlaybackInfoRequest.


        :param max_audio_channels: The max_audio_channels of this PlaybackInfoRequest.  # noqa: E501
        :type: int
        """

        self._max_audio_channels = max_audio_channels

    @property
    def media_source_id(self):
        """Gets the media_source_id of this PlaybackInfoRequest.  # noqa: E501


        :return: The media_source_id of this PlaybackInfoRequest.  # noqa: E501
        :rtype: str
        """
        return self._media_source_id

    @media_source_id.setter
    def media_source_id(self, media_source_id):
        """Sets the media_source_id of this PlaybackInfoRequest.


        :param media_source_id: The media_source_id of this PlaybackInfoRequest.  # noqa: E501
        :type: str
        """

        self._media_source_id = media_source_id

    @property
    def live_stream_id(self):
        """Gets the live_stream_id of this PlaybackInfoRequest.  # noqa: E501


        :return: The live_stream_id of this PlaybackInfoRequest.  # noqa: E501
        :rtype: str
        """
        return self._live_stream_id

    @live_stream_id.setter
    def live_stream_id(self, live_stream_id):
        """Sets the live_stream_id of this PlaybackInfoRequest.


        :param live_stream_id: The live_stream_id of this PlaybackInfoRequest.  # noqa: E501
        :type: str
        """

        self._live_stream_id = live_stream_id

    @property
    def device_profile(self):
        """Gets the device_profile of this PlaybackInfoRequest.  # noqa: E501


        :return: The device_profile of this PlaybackInfoRequest.  # noqa: E501
        :rtype: DeviceProfile
        """
        return self._device_profile

    @device_profile.setter
    def device_profile(self, device_profile):
        """Sets the device_profile of this PlaybackInfoRequest.


        :param device_profile: The device_profile of this PlaybackInfoRequest.  # noqa: E501
        :type: DeviceProfile
        """

        self._device_profile = device_profile

    @property
    def enable_direct_play(self):
        """Gets the enable_direct_play of this PlaybackInfoRequest.  # noqa: E501


        :return: The enable_direct_play of this PlaybackInfoRequest.  # noqa: E501
        :rtype: bool
        """
        return self._enable_direct_play

    @enable_direct_play.setter
    def enable_direct_play(self, enable_direct_play):
        """Sets the enable_direct_play of this PlaybackInfoRequest.


        :param enable_direct_play: The enable_direct_play of this PlaybackInfoRequest.  # noqa: E501
        :type: bool
        """

        self._enable_direct_play = enable_direct_play

    @property
    def enable_direct_stream(self):
        """Gets the enable_direct_stream of this PlaybackInfoRequest.  # noqa: E501


        :return: The enable_direct_stream of this PlaybackInfoRequest.  # noqa: E501
        :rtype: bool
        """
        return self._enable_direct_stream

    @enable_direct_stream.setter
    def enable_direct_stream(self, enable_direct_stream):
        """Sets the enable_direct_stream of this PlaybackInfoRequest.


        :param enable_direct_stream: The enable_direct_stream of this PlaybackInfoRequest.  # noqa: E501
        :type: bool
        """

        self._enable_direct_stream = enable_direct_stream

    @property
    def enable_transcoding(self):
        """Gets the enable_transcoding of this PlaybackInfoRequest.  # noqa: E501


        :return: The enable_transcoding of this PlaybackInfoRequest.  # noqa: E501
        :rtype: bool
        """
        return self._enable_transcoding

    @enable_transcoding.setter
    def enable_transcoding(self, enable_transcoding):
        """Sets the enable_transcoding of this PlaybackInfoRequest.


        :param enable_transcoding: The enable_transcoding of this PlaybackInfoRequest.  # noqa: E501
        :type: bool
        """

        self._enable_transcoding = enable_transcoding

    @property
    def allow_interlaced_video_stream_copy(self):
        """Gets the allow_interlaced_video_stream_copy of this PlaybackInfoRequest.  # noqa: E501


        :return: The allow_interlaced_video_stream_copy of this PlaybackInfoRequest.  # noqa: E501
        :rtype: bool
        """
        return self._allow_interlaced_video_stream_copy

    @allow_interlaced_video_stream_copy.setter
    def allow_interlaced_video_stream_copy(self, allow_interlaced_video_stream_copy):
        """Sets the allow_interlaced_video_stream_copy of this PlaybackInfoRequest.


        :param allow_interlaced_video_stream_copy: The allow_interlaced_video_stream_copy of this PlaybackInfoRequest.  # noqa: E501
        :type: bool
        """

        self._allow_interlaced_video_stream_copy = allow_interlaced_video_stream_copy

    @property
    def allow_video_stream_copy(self):
        """Gets the allow_video_stream_copy of this PlaybackInfoRequest.  # noqa: E501


        :return: The allow_video_stream_copy of this PlaybackInfoRequest.  # noqa: E501
        :rtype: bool
        """
        return self._allow_video_stream_copy

    @allow_video_stream_copy.setter
    def allow_video_stream_copy(self, allow_video_stream_copy):
        """Sets the allow_video_stream_copy of this PlaybackInfoRequest.


        :param allow_video_stream_copy: The allow_video_stream_copy of this PlaybackInfoRequest.  # noqa: E501
        :type: bool
        """

        self._allow_video_stream_copy = allow_video_stream_copy

    @property
    def allow_audio_stream_copy(self):
        """Gets the allow_audio_stream_copy of this PlaybackInfoRequest.  # noqa: E501


        :return: The allow_audio_stream_copy of this PlaybackInfoRequest.  # noqa: E501
        :rtype: bool
        """
        return self._allow_audio_stream_copy

    @allow_audio_stream_copy.setter
    def allow_audio_stream_copy(self, allow_audio_stream_copy):
        """Sets the allow_audio_stream_copy of this PlaybackInfoRequest.


        :param allow_audio_stream_copy: The allow_audio_stream_copy of this PlaybackInfoRequest.  # noqa: E501
        :type: bool
        """

        self._allow_audio_stream_copy = allow_audio_stream_copy

    @property
    def is_playback(self):
        """Gets the is_playback of this PlaybackInfoRequest.  # noqa: E501


        :return: The is_playback of this PlaybackInfoRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_playback

    @is_playback.setter
    def is_playback(self, is_playback):
        """Sets the is_playback of this PlaybackInfoRequest.


        :param is_playback: The is_playback of this PlaybackInfoRequest.  # noqa: E501
        :type: bool
        """

        self._is_playback = is_playback

    @property
    def auto_open_live_stream(self):
        """Gets the auto_open_live_stream of this PlaybackInfoRequest.  # noqa: E501


        :return: The auto_open_live_stream of this PlaybackInfoRequest.  # noqa: E501
        :rtype: bool
        """
        return self._auto_open_live_stream

    @auto_open_live_stream.setter
    def auto_open_live_stream(self, auto_open_live_stream):
        """Sets the auto_open_live_stream of this PlaybackInfoRequest.


        :param auto_open_live_stream: The auto_open_live_stream of this PlaybackInfoRequest.  # noqa: E501
        :type: bool
        """

        self._auto_open_live_stream = auto_open_live_stream

    @property
    def current_play_session_id(self):
        """Gets the current_play_session_id of this PlaybackInfoRequest.  # noqa: E501


        :return: The current_play_session_id of this PlaybackInfoRequest.  # noqa: E501
        :rtype: str
        """
        return self._current_play_session_id

    @current_play_session_id.setter
    def current_play_session_id(self, current_play_session_id):
        """Sets the current_play_session_id of this PlaybackInfoRequest.


        :param current_play_session_id: The current_play_session_id of this PlaybackInfoRequest.  # noqa: E501
        :type: str
        """

        self._current_play_session_id = current_play_session_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PlaybackInfoRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlaybackInfoRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class CommonInterfacesICodecDeviceCapabilities(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'supports_hw_upload': 'bool',
        'supports_hw_download': 'bool',
        'supports_standalone_device_init': 'bool',
        'supports10_bit_processing': 'bool',
        'supports_native_tone_mapping': 'bool'
    }

    attribute_map = {
        'supports_hw_upload': 'SupportsHwUpload',
        'supports_hw_download': 'SupportsHwDownload',
        'supports_standalone_device_init': 'SupportsStandaloneDeviceInit',
        'supports10_bit_processing': 'Supports10BitProcessing',
        'supports_native_tone_mapping': 'SupportsNativeToneMapping'
    }

    def __init__(self, supports_hw_upload=None, supports_hw_download=None, supports_standalone_device_init=None, supports10_bit_processing=None, supports_native_tone_mapping=None):  # noqa: E501
        """CommonInterfacesICodecDeviceCapabilities - a model defined in Swagger"""  # noqa: E501
        self._supports_hw_upload = None
        self._supports_hw_download = None
        self._supports_standalone_device_init = None
        self._supports10_bit_processing = None
        self._supports_native_tone_mapping = None
        self.discriminator = None
        if supports_hw_upload is not None:
            self.supports_hw_upload = supports_hw_upload
        if supports_hw_download is not None:
            self.supports_hw_download = supports_hw_download
        if supports_standalone_device_init is not None:
            self.supports_standalone_device_init = supports_standalone_device_init
        if supports10_bit_processing is not None:
            self.supports10_bit_processing = supports10_bit_processing
        if supports_native_tone_mapping is not None:
            self.supports_native_tone_mapping = supports_native_tone_mapping

    @property
    def supports_hw_upload(self):
        """Gets the supports_hw_upload of this CommonInterfacesICodecDeviceCapabilities.  # noqa: E501


        :return: The supports_hw_upload of this CommonInterfacesICodecDeviceCapabilities.  # noqa: E501
        :rtype: bool
        """
        return self._supports_hw_upload

    @supports_hw_upload.setter
    def supports_hw_upload(self, supports_hw_upload):
        """Sets the supports_hw_upload of this CommonInterfacesICodecDeviceCapabilities.


        :param supports_hw_upload: The supports_hw_upload of this CommonInterfacesICodecDeviceCapabilities.  # noqa: E501
        :type: bool
        """

        self._supports_hw_upload = supports_hw_upload

    @property
    def supports_hw_download(self):
        """Gets the supports_hw_download of this CommonInterfacesICodecDeviceCapabilities.  # noqa: E501


        :return: The supports_hw_download of this CommonInterfacesICodecDeviceCapabilities.  # noqa: E501
        :rtype: bool
        """
        return self._supports_hw_download

    @supports_hw_download.setter
    def supports_hw_download(self, supports_hw_download):
        """Sets the supports_hw_download of this CommonInterfacesICodecDeviceCapabilities.


        :param supports_hw_download: The supports_hw_download of this CommonInterfacesICodecDeviceCapabilities.  # noqa: E501
        :type: bool
        """

        self._supports_hw_download = supports_hw_download

    @property
    def supports_standalone_device_init(self):
        """Gets the supports_standalone_device_init of this CommonInterfacesICodecDeviceCapabilities.  # noqa: E501


        :return: The supports_standalone_device_init of this CommonInterfacesICodecDeviceCapabilities.  # noqa: E501
        :rtype: bool
        """
        return self._supports_standalone_device_init

    @supports_standalone_device_init.setter
    def supports_standalone_device_init(self, supports_standalone_device_init):
        """Sets the supports_standalone_device_init of this CommonInterfacesICodecDeviceCapabilities.


        :param supports_standalone_device_init: The supports_standalone_device_init of this CommonInterfacesICodecDeviceCapabilities.  # noqa: E501
        :type: bool
        """

        self._supports_standalone_device_init = supports_standalone_device_init

    @property
    def supports10_bit_processing(self):
        """Gets the supports10_bit_processing of this CommonInterfacesICodecDeviceCapabilities.  # noqa: E501


        :return: The supports10_bit_processing of this CommonInterfacesICodecDeviceCapabilities.  # noqa: E501
        :rtype: bool
        """
        return self._supports10_bit_processing

    @supports10_bit_processing.setter
    def supports10_bit_processing(self, supports10_bit_processing):
        """Sets the supports10_bit_processing of this CommonInterfacesICodecDeviceCapabilities.


        :param supports10_bit_processing: The supports10_bit_processing of this CommonInterfacesICodecDeviceCapabilities.  # noqa: E501
        :type: bool
        """

        self._supports10_bit_processing = supports10_bit_processing

    @property
    def supports_native_tone_mapping(self):
        """Gets the supports_native_tone_mapping of this CommonInterfacesICodecDeviceCapabilities.  # noqa: E501


        :return: The supports_native_tone_mapping of this CommonInterfacesICodecDeviceCapabilities.  # noqa: E501
        :rtype: bool
        """
        return self._supports_native_tone_mapping

    @supports_native_tone_mapping.setter
    def supports_native_tone_mapping(self, supports_native_tone_mapping):
        """Sets the supports_native_tone_mapping of this CommonInterfacesICodecDeviceCapabilities.


        :param supports_native_tone_mapping: The supports_native_tone_mapping of this CommonInterfacesICodecDeviceCapabilities.  # noqa: E501
        :type: bool
        """

        self._supports_native_tone_mapping = supports_native_tone_mapping

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CommonInterfacesICodecDeviceCapabilities, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CommonInterfacesICodecDeviceCapabilities):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class LibraryOptions(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'enable_archive_media_files': 'bool',
        'enable_photos': 'bool',
        'enable_realtime_monitor': 'bool',
        'enable_marker_detection': 'bool',
        'enable_marker_detection_during_library_scan': 'bool',
        'intro_detection_fingerprint_length': 'int',
        'enable_chapter_image_extraction': 'bool',
        'extract_chapter_images_during_library_scan': 'bool',
        'download_images_in_advance': 'bool',
        'cache_images': 'bool',
        'path_infos': 'list[MediaPathInfo]',
        'ignore_hidden_files': 'bool',
        'ignore_file_extensions': 'list[str]',
        'save_local_metadata': 'bool',
        'save_metadata_hidden': 'bool',
        'save_local_thumbnail_sets': 'bool',
        'import_playlists': 'bool',
        'enable_automatic_series_grouping': 'bool',
        'share_embedded_music_album_images': 'bool',
        'enable_embedded_titles': 'bool',
        'enable_audio_resume': 'bool',
        'auto_generate_chapters': 'bool',
        'automatic_refresh_interval_days': 'int',
        'placeholder_metadata_refresh_interval_days': 'int',
        'preferred_metadata_language': 'str',
        'preferred_image_language': 'str',
        'content_type': 'str',
        'metadata_country_code': 'str',
        'metadata_savers': 'list[str]',
        'disabled_local_metadata_readers': 'list[str]',
        'local_metadata_reader_order': 'list[str]',
        'disabled_lyrics_fetchers': 'list[str]',
        'save_lyrics_with_media': 'bool',
        'lyrics_download_max_age_days': 'int',
        'lyrics_fetcher_order': 'list[str]',
        'lyrics_download_languages': 'list[str]',
        'disabled_subtitle_fetchers': 'list[str]',
        'subtitle_fetcher_order': 'list[str]',
        'skip_subtitles_if_embedded_subtitles_present': 'bool',
        'skip_subtitles_if_audio_track_matches': 'bool',
        'subtitle_download_languages': 'list[str]',
        'subtitle_download_max_age_days': 'int',
        'require_perfect_subtitle_match': 'bool',
        'save_subtitles_with_media': 'bool',
        'forced_subtitles_only': 'bool',
        'hearing_impaired_subtitles_only': 'bool',
        'type_options': 'list[TypeOptions]',
        'collapse_single_item_folders': 'bool',
        'enable_adult_metadata': 'bool',
        'import_collections': 'bool',
        'disable_multi_version_items': 'bool',
        'disable_multi_part_items': 'bool',
        'min_collection_items': 'int',
        'music_folder_structure': 'str',
        'min_resume_pct': 'int',
        'max_resume_pct': 'int',
        'min_resume_duration_seconds': 'int',
        'thumbnail_images_interval_seconds': 'int',
        'sample_ignore_size': 'int'
    }

    attribute_map = {
        'enable_archive_media_files': 'EnableArchiveMediaFiles',
        'enable_photos': 'EnablePhotos',
        'enable_realtime_monitor': 'EnableRealtimeMonitor',
        'enable_marker_detection': 'EnableMarkerDetection',
        'enable_marker_detection_during_library_scan': 'EnableMarkerDetectionDuringLibraryScan',
        'intro_detection_fingerprint_length': 'IntroDetectionFingerprintLength',
        'enable_chapter_image_extraction': 'EnableChapterImageExtraction',
        'extract_chapter_images_during_library_scan': 'ExtractChapterImagesDuringLibraryScan',
        'download_images_in_advance': 'DownloadImagesInAdvance',
        'cache_images': 'CacheImages',
        'path_infos': 'PathInfos',
        'ignore_hidden_files': 'IgnoreHiddenFiles',
        'ignore_file_extensions': 'IgnoreFileExtensions',
        'save_local_metadata': 'SaveLocalMetadata',
        'save_metadata_hidden': 'SaveMetadataHidden',
        'save_local_thumbnail_sets': 'SaveLocalThumbnailSets',
        'import_playlists': 'ImportPlaylists',
        'enable_automatic_series_grouping': 'EnableAutomaticSeriesGrouping',
        'share_embedded_music_album_images': 'ShareEmbeddedMusicAlbumImages',
        'enable_embedded_titles': 'EnableEmbeddedTitles',
        'enable_audio_resume': 'EnableAudioResume',
        'auto_generate_chapters': 'AutoGenerateChapters',
        'automatic_refresh_interval_days': 'AutomaticRefreshIntervalDays',
        'placeholder_metadata_refresh_interval_days': 'PlaceholderMetadataRefreshIntervalDays',
        'preferred_metadata_language': 'PreferredMetadataLanguage',
        'preferred_image_language': 'PreferredImageLanguage',
        'content_type': 'ContentType',
        'metadata_country_code': 'MetadataCountryCode',
        'metadata_savers': 'MetadataSavers',
        'disabled_local_metadata_readers': 'DisabledLocalMetadataReaders',
        'local_metadata_reader_order': 'LocalMetadataReaderOrder',
        'disabled_lyrics_fetchers': 'DisabledLyricsFetchers',
        'save_lyrics_with_media': 'SaveLyricsWithMedia',
        'lyrics_download_max_age_days': 'LyricsDownloadMaxAgeDays',
        'lyrics_fetcher_order': 'LyricsFetcherOrder',
        'lyrics_download_languages': 'LyricsDownloadLanguages',
        'disabled_subtitle_fetchers': 'DisabledSubtitleFetchers',
        'subtitle_fetcher_order': 'SubtitleFetcherOrder',
        'skip_subtitles_if_embedded_subtitles_present': 'SkipSubtitlesIfEmbeddedSubtitlesPresent',
        'skip_subtitles_if_audio_track_matches': 'SkipSubtitlesIfAudioTrackMatches',
        'subtitle_download_languages': 'SubtitleDownloadLanguages',
        'subtitle_download_max_age_days': 'SubtitleDownloadMaxAgeDays',
        'require_perfect_subtitle_match': 'RequirePerfectSubtitleMatch',
        'save_subtitles_with_media': 'SaveSubtitlesWithMedia',
        'forced_subtitles_only': 'ForcedSubtitlesOnly',
        'hearing_impaired_subtitles_only': 'HearingImpairedSubtitlesOnly',
        'type_options': 'TypeOptions',
        'collapse_single_item_folders': 'CollapseSingleItemFolders',
        'enable_adult_metadata': 'EnableAdultMetadata',
        'import_collections': 'ImportCollections',
        'disable_multi_version_items': 'DisableMultiVersionItems',
        'disable_multi_part_items': 'DisableMultiPartItems',
        'min_collection_items': 'MinCollectionItems',
        'music_folder_structure': 'MusicFolderStructure',
        'min_resume_pct': 'MinResumePct',
        'max_resume_pct': 'MaxResumePct',
        'min_resume_duration_seconds': 'MinResumeDurationSeconds',
        'thumbnail_images_interval_seconds': 'ThumbnailImagesIntervalSeconds',
        'sample_ignore_size': 'SampleIgnoreSize'
    }

    def __init__(self, enable_archive_media_files=None, enable_photos=None, enable_realtime_monitor=None, enable_marker_detection=None, enable_marker_detection_during_library_scan=None, intro_detection_fingerprint_length=None, enable_chapter_image_extraction=None, extract_chapter_images_during_library_scan=None, download_images_in_advance=None, cache_images=None, path_infos=None, ignore_hidden_files=None, ignore_file_extensions=None, save_local_metadata=None, save_metadata_hidden=None, save_local_thumbnail_sets=None, import_playlists=None, enable_automatic_series_grouping=None, share_embedded_music_album_images=None, enable_embedded_titles=None, enable_audio_resume=None, auto_generate_chapters=None, automatic_refresh_interval_days=None, placeholder_metadata_refresh_interval_days=None, preferred_metadata_language=None, preferred_image_language=None, content_type=None, metadata_country_code=None, metadata_savers=None, disabled_local_metadata_readers=None, local_metadata_reader_order=None, disabled_lyrics_fetchers=None, save_lyrics_with_media=None, lyrics_download_max_age_days=None, lyrics_fetcher_order=None, lyrics_download_languages=None, disabled_subtitle_fetchers=None, subtitle_fetcher_order=None, skip_subtitles_if_embedded_subtitles_present=None, skip_subtitles_if_audio_track_matches=None, subtitle_download_languages=None, subtitle_download_max_age_days=None, require_perfect_subtitle_match=None, save_subtitles_with_media=None, forced_subtitles_only=None, hearing_impaired_subtitles_only=None, type_options=None, collapse_single_item_folders=None, enable_adult_metadata=None, import_collections=None, disable_multi_version_items=None, disable_multi_part_items=None, min_collection_items=None, music_folder_structure=None, min_resume_pct=None, max_resume_pct=None, min_resume_duration_seconds=None, thumbnail_images_interval_seconds=None, sample_ignore_size=None):  # noqa: E501
        """LibraryOptions - a model defined in Swagger"""  # noqa: E501
        self._enable_archive_media_files = None
        self._enable_photos = None
        self._enable_realtime_monitor = None
        self._enable_marker_detection = None
        self._enable_marker_detection_during_library_scan = None
        self._intro_detection_fingerprint_length = None
        self._enable_chapter_image_extraction = None
        self._extract_chapter_images_during_library_scan = None
        self._download_images_in_advance = None
        self._cache_images = None
        self._path_infos = None
        self._ignore_hidden_files = None
        self._ignore_file_extensions = None
        self._save_local_metadata = None
        self._save_metadata_hidden = None
        self._save_local_thumbnail_sets = None
        self._import_playlists = None
        self._enable_automatic_series_grouping = None
        self._share_embedded_music_album_images = None
        self._enable_embedded_titles = None
        self._enable_audio_resume = None
        self._auto_generate_chapters = None
        self._automatic_refresh_interval_days = None
        self._placeholder_metadata_refresh_interval_days = None
        self._preferred_metadata_language = None
        self._preferred_image_language = None
        self._content_type = None
        self._metadata_country_code = None
        self._metadata_savers = None
        self._disabled_local_metadata_readers = None
        self._local_metadata_reader_order = None
        self._disabled_lyrics_fetchers = None
        self._save_lyrics_with_media = None
        self._lyrics_download_max_age_days = None
        self._lyrics_fetcher_order = None
        self._lyrics_download_languages = None
        self._disabled_subtitle_fetchers = None
        self._subtitle_fetcher_order = None
        self._skip_subtitles_if_embedded_subtitles_present = None
        self._skip_subtitles_if_audio_track_matches = None
        self._subtitle_download_languages = None
        self._subtitle_download_max_age_days = None
        self._require_perfect_subtitle_match = None
        self._save_subtitles_with_media = None
        self._forced_subtitles_only = None
        self._hearing_impaired_subtitles_only = None
        self._type_options = None
        self._collapse_single_item_folders = None
        self._enable_adult_metadata = None
        self._import_collections = None
        self._disable_multi_version_items = None
        self._disable_multi_part_items = None
        self._min_collection_items = None
        self._music_folder_structure = None
        self._min_resume_pct = None
        self._max_resume_pct = None
        self._min_resume_duration_seconds = None
        self._thumbnail_images_interval_seconds = None
        self._sample_ignore_size = None
        self.discriminator = None
        if enable_archive_media_files is not None:
            self.enable_archive_media_files = enable_archive_media_files
        if enable_photos is not None:
            self.enable_photos = enable_photos
        if enable_realtime_monitor is not None:
            self.enable_realtime_monitor = enable_realtime_monitor
        if enable_marker_detection is not None:
            self.enable_marker_detection = enable_marker_detection
        if enable_marker_detection_during_library_scan is not None:
            self.enable_marker_detection_during_library_scan = enable_marker_detection_during_library_scan
        if intro_detection_fingerprint_length is not None:
            self.intro_detection_fingerprint_length = intro_detection_fingerprint_length
        if enable_chapter_image_extraction is not None:
            self.enable_chapter_image_extraction = enable_chapter_image_extraction
        if extract_chapter_images_during_library_scan is not None:
            self.extract_chapter_images_during_library_scan = extract_chapter_images_during_library_scan
        if download_images_in_advance is not None:
            self.download_images_in_advance = download_images_in_advance
        if cache_images is not None:
            self.cache_images = cache_images
        if path_infos is not None:
            self.path_infos = path_infos
        if ignore_hidden_files is not None:
            self.ignore_hidden_files = ignore_hidden_files
        if ignore_file_extensions is not None:
            self.ignore_file_extensions = ignore_file_extensions
        if save_local_metadata is not None:
            self.save_local_metadata = save_local_metadata
        if save_metadata_hidden is not None:
            self.save_metadata_hidden = save_metadata_hidden
        if save_local_thumbnail_sets is not None:
            self.save_local_thumbnail_sets = save_local_thumbnail_sets
        if import_playlists is not None:
            self.import_playlists = import_playlists
        if enable_automatic_series_grouping is not None:
            self.enable_automatic_series_grouping = enable_automatic_series_grouping
        if share_embedded_music_album_images is not None:
            self.share_embedded_music_album_images = share_embedded_music_album_images
        if enable_embedded_titles is not None:
            self.enable_embedded_titles = enable_embedded_titles
        if enable_audio_resume is not None:
            self.enable_audio_resume = enable_audio_resume
        if auto_generate_chapters is not None:
            self.auto_generate_chapters = auto_generate_chapters
        if automatic_refresh_interval_days is not None:
            self.automatic_refresh_interval_days = automatic_refresh_interval_days
        if placeholder_metadata_refresh_interval_days is not None:
            self.placeholder_metadata_refresh_interval_days = placeholder_metadata_refresh_interval_days
        if preferred_metadata_language is not None:
            self.preferred_metadata_language = preferred_metadata_language
        if preferred_image_language is not None:
            self.preferred_image_language = preferred_image_language
        if content_type is not None:
            self.content_type = content_type
        if metadata_country_code is not None:
            self.metadata_country_code = metadata_country_code
        if metadata_savers is not None:
            self.metadata_savers = metadata_savers
        if disabled_local_metadata_readers is not None:
            self.disabled_local_metadata_readers = disabled_local_metadata_readers
        if local_metadata_reader_order is not None:
            self.local_metadata_reader_order = local_metadata_reader_order
        if disabled_lyrics_fetchers is not None:
            self.disabled_lyrics_fetchers = disabled_lyrics_fetchers
        if save_lyrics_with_media is not None:
            self.save_lyrics_with_media = save_lyrics_with_media
        if lyrics_download_max_age_days is not None:
            self.lyrics_download_max_age_days = lyrics_download_max_age_days
        if lyrics_fetcher_order is not None:
            self.lyrics_fetcher_order = lyrics_fetcher_order
        if lyrics_download_languages is not None:
            self.lyrics_download_languages = lyrics_download_languages
        if disabled_subtitle_fetchers is not None:
            self.disabled_subtitle_fetchers = disabled_subtitle_fetchers
        if subtitle_fetcher_order is not None:
            self.subtitle_fetcher_order = subtitle_fetcher_order
        if skip_subtitles_if_embedded_subtitles_present is not None:
            self.skip_subtitles_if_embedded_subtitles_present = skip_subtitles_if_embedded_subtitles_present
        if skip_subtitles_if_audio_track_matches is not None:
            self.skip_subtitles_if_audio_track_matches = skip_subtitles_if_audio_track_matches
        if subtitle_download_languages is not None:
            self.subtitle_download_languages = subtitle_download_languages
        if subtitle_download_max_age_days is not None:
            self.subtitle_download_max_age_days = subtitle_download_max_age_days
        if require_perfect_subtitle_match is not None:
            self.require_perfect_subtitle_match = require_perfect_subtitle_match
        if save_subtitles_with_media is not None:
            self.save_subtitles_with_media = save_subtitles_with_media
        if forced_subtitles_only is not None:
            self.forced_subtitles_only = forced_subtitles_only
        if hearing_impaired_subtitles_only is not None:
            self.hearing_impaired_subtitles_only = hearing_impaired_subtitles_only
        if type_options is not None:
            self.type_options = type_options
        if collapse_single_item_folders is not None:
            self.collapse_single_item_folders = collapse_single_item_folders
        if enable_adult_metadata is not None:
            self.enable_adult_metadata = enable_adult_metadata
        if import_collections is not None:
            self.import_collections = import_collections
        if disable_multi_version_items is not None:
            self.disable_multi_version_items = disable_multi_version_items
        if disable_multi_part_items is not None:
            self.disable_multi_part_items = disable_multi_part_items
        if min_collection_items is not None:
            self.min_collection_items = min_collection_items
        if music_folder_structure is not None:
            self.music_folder_structure = music_folder_structure
        if min_resume_pct is not None:
            self.min_resume_pct = min_resume_pct
        if max_resume_pct is not None:
            self.max_resume_pct = max_resume_pct
        if min_resume_duration_seconds is not None:
            self.min_resume_duration_seconds = min_resume_duration_seconds
        if thumbnail_images_interval_seconds is not None:
            self.thumbnail_images_interval_seconds = thumbnail_images_interval_seconds
        if sample_ignore_size is not None:
            self.sample_ignore_size = sample_ignore_size

    @property
    def enable_archive_media_files(self):
        """Gets the enable_archive_media_files of this LibraryOptions.  # noqa: E501


        :return: The enable_archive_media_files of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._enable_archive_media_files

    @enable_archive_media_files.setter
    def enable_archive_media_files(self, enable_archive_media_files):
        """Sets the enable_archive_media_files of this LibraryOptions.


        :param enable_archive_media_files: The enable_archive_media_files of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._enable_archive_media_files = enable_archive_media_files

    @property
    def enable_photos(self):
        """Gets the enable_photos of this LibraryOptions.  # noqa: E501


        :return: The enable_photos of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._enable_photos

    @enable_photos.setter
    def enable_photos(self, enable_photos):
        """Sets the enable_photos of this LibraryOptions.


        :param enable_photos: The enable_photos of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._enable_photos = enable_photos

    @property
    def enable_realtime_monitor(self):
        """Gets the enable_realtime_monitor of this LibraryOptions.  # noqa: E501


        :return: The enable_realtime_monitor of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._enable_realtime_monitor

    @enable_realtime_monitor.setter
    def enable_realtime_monitor(self, enable_realtime_monitor):
        """Sets the enable_realtime_monitor of this LibraryOptions.


        :param enable_realtime_monitor: The enable_realtime_monitor of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._enable_realtime_monitor = enable_realtime_monitor

    @property
    def enable_marker_detection(self):
        """Gets the enable_marker_detection of this LibraryOptions.  # noqa: E501


        :return: The enable_marker_detection of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._enable_marker_detection

    @enable_marker_detection.setter
    def enable_marker_detection(self, enable_marker_detection):
        """Sets the enable_marker_detection of this LibraryOptions.


        :param enable_marker_detection: The enable_marker_detection of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._enable_marker_detection = enable_marker_detection

    @property
    def enable_marker_detection_during_library_scan(self):
        """Gets the enable_marker_detection_during_library_scan of this LibraryOptions.  # noqa: E501


        :return: The enable_marker_detection_during_library_scan of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._enable_marker_detection_during_library_scan

    @enable_marker_detection_during_library_scan.setter
    def enable_marker_detection_during_library_scan(self, enable_marker_detection_during_library_scan):
        """Sets the enable_marker_detection_during_library_scan of this LibraryOptions.


        :param enable_marker_detection_during_library_scan: The enable_marker_detection_during_library_scan of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._enable_marker_detection_during_library_scan = enable_marker_detection_during_library_scan

    @property
    def intro_detection_fingerprint_length(self):
        """Gets the intro_detection_fingerprint_length of this LibraryOptions.  # noqa: E501


        :return: The intro_detection_fingerprint_length of this LibraryOptions.  # noqa: E501
        :rtype: int
        """
        return self._intro_detection_fingerprint_length

    @intro_detection_fingerprint_length.setter
    def intro_detection_fingerprint_length(self, intro_detection_fingerprint_length):
        """Sets the intro_detection_fingerprint_length of this LibraryOptions.


        :param intro_detection_fingerprint_length: The intro_detection_fingerprint_length of this LibraryOptions.  # noqa: E501
        :type: int
        """

        self._intro_detection_fingerprint_length = intro_detection_fingerprint_length

    @property
    def enable_chapter_image_extraction(self):
        """Gets the enable_chapter_image_extraction of this LibraryOptions.  # noqa: E501


        :return: The enable_chapter_image_extraction of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._enable_chapter_image_extraction

    @enable_chapter_image_extraction.setter
    def enable_chapter_image_extraction(self, enable_chapter_image_extraction):
        """Sets the enable_chapter_image_extraction of this LibraryOptions.


        :param enable_chapter_image_extraction: The enable_chapter_image_extraction of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._enable_chapter_image_extraction = enable_chapter_image_extraction

    @property
    def extract_chapter_images_during_library_scan(self):
        """Gets the extract_chapter_images_during_library_scan of this LibraryOptions.  # noqa: E501


        :return: The extract_chapter_images_during_library_scan of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._extract_chapter_images_during_library_scan

    @extract_chapter_images_during_library_scan.setter
    def extract_chapter_images_during_library_scan(self, extract_chapter_images_during_library_scan):
        """Sets the extract_chapter_images_during_library_scan of this LibraryOptions.


        :param extract_chapter_images_during_library_scan: The extract_chapter_images_during_library_scan of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._extract_chapter_images_during_library_scan = extract_chapter_images_during_library_scan

    @property
    def download_images_in_advance(self):
        """Gets the download_images_in_advance of this LibraryOptions.  # noqa: E501


        :return: The download_images_in_advance of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._download_images_in_advance

    @download_images_in_advance.setter
    def download_images_in_advance(self, download_images_in_advance):
        """Sets the download_images_in_advance of this LibraryOptions.


        :param download_images_in_advance: The download_images_in_advance of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._download_images_in_advance = download_images_in_advance

    @property
    def cache_images(self):
        """Gets the cache_images of this LibraryOptions.  # noqa: E501


        :return: The cache_images of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._cache_images

    @cache_images.setter
    def cache_images(self, cache_images):
        """Sets the cache_images of this LibraryOptions.


        :param cache_images: The cache_images of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._cache_images = cache_images

    @property
    def path_infos(self):
        """Gets the path_infos of this LibraryOptions.  # noqa: E501


        :return: The path_infos of this LibraryOptions.  # noqa: E501
        :rtype: list[MediaPathInfo]
        """
        return self._path_infos

    @path_infos.setter
    def path_infos(self, path_infos):
        """Sets the path_infos of this LibraryOptions.


        :param path_infos: The path_infos of this LibraryOptions.  # noqa: E501
        :type: list[MediaPathInfo]
        """

        self._path_infos = path_infos

    @property
    def ignore_hidden_files(self):
        """Gets the ignore_hidden_files of this LibraryOptions.  # noqa: E501


        :return: The ignore_hidden_files of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._ignore_hidden_files

    @ignore_hidden_files.setter
    def ignore_hidden_files(self, ignore_hidden_files):
        """Sets the ignore_hidden_files of this LibraryOptions.


        :param ignore_hidden_files: The ignore_hidden_files of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._ignore_hidden_files = ignore_hidden_files

    @property
    def ignore_file_extensions(self):
        """Gets the ignore_file_extensions of this LibraryOptions.  # noqa: E501


        :return: The ignore_file_extensions of this LibraryOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._ignore_file_extensions

    @ignore_file_extensions.setter
    def ignore_file_extensions(self, ignore_file_extensions):
        """Sets the ignore_file_extensions of this LibraryOptions.


        :param ignore_file_extensions: The ignore_file_extensions of this LibraryOptions.  # noqa: E501
        :type: list[str]
        """

        self._ignore_file_extensions = ignore_file_extensions

    @property
    def save_local_metadata(self):
        """Gets the save_local_metadata of this LibraryOptions.  # noqa: E501


        :return: The save_local_metadata of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._save_local_metadata

    @save_local_metadata.setter
    def save_local_metadata(self, save_local_metadata):
        """Sets the save_local_metadata of this LibraryOptions.


        :param save_local_metadata: The save_local_metadata of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._save_local_metadata = save_local_metadata

    @property
    def save_metadata_hidden(self):
        """Gets the save_metadata_hidden of this LibraryOptions.  # noqa: E501


        :return: The save_metadata_hidden of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._save_metadata_hidden

    @save_metadata_hidden.setter
    def save_metadata_hidden(self, save_metadata_hidden):
        """Sets the save_metadata_hidden of this LibraryOptions.


        :param save_metadata_hidden: The save_metadata_hidden of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._save_metadata_hidden = save_metadata_hidden

    @property
    def save_local_thumbnail_sets(self):
        """Gets the save_local_thumbnail_sets of this LibraryOptions.  # noqa: E501


        :return: The save_local_thumbnail_sets of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._save_local_thumbnail_sets

    @save_local_thumbnail_sets.setter
    def save_local_thumbnail_sets(self, save_local_thumbnail_sets):
        """Sets the save_local_thumbnail_sets of this LibraryOptions.


        :param save_local_thumbnail_sets: The save_local_thumbnail_sets of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._save_local_thumbnail_sets = save_local_thumbnail_sets

    @property
    def import_playlists(self):
        """Gets the import_playlists of this LibraryOptions.  # noqa: E501


        :return: The import_playlists of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._import_playlists

    @import_playlists.setter
    def import_playlists(self, import_playlists):
        """Sets the import_playlists of this LibraryOptions.


        :param import_playlists: The import_playlists of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._import_playlists = import_playlists

    @property
    def enable_automatic_series_grouping(self):
        """Gets the enable_automatic_series_grouping of this LibraryOptions.  # noqa: E501


        :return: The enable_automatic_series_grouping of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._enable_automatic_series_grouping

    @enable_automatic_series_grouping.setter
    def enable_automatic_series_grouping(self, enable_automatic_series_grouping):
        """Sets the enable_automatic_series_grouping of this LibraryOptions.


        :param enable_automatic_series_grouping: The enable_automatic_series_grouping of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._enable_automatic_series_grouping = enable_automatic_series_grouping

    @property
    def share_embedded_music_album_images(self):
        """Gets the share_embedded_music_album_images of this LibraryOptions.  # noqa: E501


        :return: The share_embedded_music_album_images of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._share_embedded_music_album_images

    @share_embedded_music_album_images.setter
    def share_embedded_music_album_images(self, share_embedded_music_album_images):
        """Sets the share_embedded_music_album_images of this LibraryOptions.


        :param share_embedded_music_album_images: The share_embedded_music_album_images of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._share_embedded_music_album_images = share_embedded_music_album_images

    @property
    def enable_embedded_titles(self):
        """Gets the enable_embedded_titles of this LibraryOptions.  # noqa: E501


        :return: The enable_embedded_titles of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._enable_embedded_titles

    @enable_embedded_titles.setter
    def enable_embedded_titles(self, enable_embedded_titles):
        """Sets the enable_embedded_titles of this LibraryOptions.


        :param enable_embedded_titles: The enable_embedded_titles of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._enable_embedded_titles = enable_embedded_titles

    @property
    def enable_audio_resume(self):
        """Gets the enable_audio_resume of this LibraryOptions.  # noqa: E501


        :return: The enable_audio_resume of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._enable_audio_resume

    @enable_audio_resume.setter
    def enable_audio_resume(self, enable_audio_resume):
        """Sets the enable_audio_resume of this LibraryOptions.


        :param enable_audio_resume: The enable_audio_resume of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._enable_audio_resume = enable_audio_resume

    @property
    def auto_generate_chapters(self):
        """Gets the auto_generate_chapters of this LibraryOptions.  # noqa: E501


        :return: The auto_generate_chapters of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._auto_generate_chapters

    @auto_generate_chapters.setter
    def auto_generate_chapters(self, auto_generate_chapters):
        """Sets the auto_generate_chapters of this LibraryOptions.


        :param auto_generate_chapters: The auto_generate_chapters of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._auto_generate_chapters = auto_generate_chapters

    @property
    def automatic_refresh_interval_days(self):
        """Gets the automatic_refresh_interval_days of this LibraryOptions.  # noqa: E501


        :return: The automatic_refresh_interval_days of this LibraryOptions.  # noqa: E501
        :rtype: int
        """
        return self._automatic_refresh_interval_days

    @automatic_refresh_interval_days.setter
    def automatic_refresh_interval_days(self, automatic_refresh_interval_days):
        """Sets the automatic_refresh_interval_days of this LibraryOptions.


        :param automatic_refresh_interval_days: The automatic_refresh_interval_days of this LibraryOptions.  # noqa: E501
        :type: int
        """

        self._automatic_refresh_interval_days = automatic_refresh_interval_days

    @property
    def placeholder_metadata_refresh_interval_days(self):
        """Gets the placeholder_metadata_refresh_interval_days of this LibraryOptions.  # noqa: E501


        :return: The placeholder_metadata_refresh_interval_days of this LibraryOptions.  # noqa: E501
        :rtype: int
        """
        return self._placeholder_metadata_refresh_interval_days

    @placeholder_metadata_refresh_interval_days.setter
    def placeholder_metadata_refresh_interval_days(self, placeholder_metadata_refresh_interval_days):
        """Sets the placeholder_metadata_refresh_interval_days of this LibraryOptions.


        :param placeholder_metadata_refresh_interval_days: The placeholder_metadata_refresh_interval_days of this LibraryOptions.  # noqa: E501
        :type: int
        """

        self._placeholder_metadata_refresh_interval_days = placeholder_metadata_refresh_interval_days

    @property
    def preferred_metadata_language(self):
        """Gets the preferred_metadata_language of this LibraryOptions.  # noqa: E501

        The preferred metadata language.  # noqa: E501

        :return: The preferred_metadata_language of this LibraryOptions.  # noqa: E501
        :rtype: str
        """
        return self._preferred_metadata_language

    @preferred_metadata_language.setter
    def preferred_metadata_language(self, preferred_metadata_language):
        """Sets the preferred_metadata_language of this LibraryOptions.

        The preferred metadata language.  # noqa: E501

        :param preferred_metadata_language: The preferred_metadata_language of this LibraryOptions.  # noqa: E501
        :type: str
        """

        self._preferred_metadata_language = preferred_metadata_language

    @property
    def preferred_image_language(self):
        """Gets the preferred_image_language of this LibraryOptions.  # noqa: E501


        :return: The preferred_image_language of this LibraryOptions.  # noqa: E501
        :rtype: str
        """
        return self._preferred_image_language

    @preferred_image_language.setter
    def preferred_image_language(self, preferred_image_language):
        """Sets the preferred_image_language of this LibraryOptions.


        :param preferred_image_language: The preferred_image_language of this LibraryOptions.  # noqa: E501
        :type: str
        """

        self._preferred_image_language = preferred_image_language

    @property
    def content_type(self):
        """Gets the content_type of this LibraryOptions.  # noqa: E501


        :return: The content_type of this LibraryOptions.  # noqa: E501
        :rtype: str
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """Sets the content_type of this LibraryOptions.


        :param content_type: The content_type of this LibraryOptions.  # noqa: E501
        :type: str
        """

        self._content_type = content_type

    @property
    def metadata_country_code(self):
        """Gets the metadata_country_code of this LibraryOptions.  # noqa: E501

        The metadata country code.  # noqa: E501

        :return: The metadata_country_code of this LibraryOptions.  # noqa: E501
        :rtype: str
        """
        return self._metadata_country_code

    @metadata_country_code.setter
    def metadata_country_code(self, metadata_country_code):
        """Sets the metadata_country_code of this LibraryOptions.

        The metadata country code.  # noqa: E501

        :param metadata_country_code: The metadata_country_code of this LibraryOptions.  # noqa: E501
        :type: str
        """

        self._metadata_country_code = metadata_country_code

    @property
    def metadata_savers(self):
        """Gets the metadata_savers of this LibraryOptions.  # noqa: E501


        :return: The metadata_savers of this LibraryOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._metadata_savers

    @metadata_savers.setter
    def metadata_savers(self, metadata_savers):
        """Sets the metadata_savers of this LibraryOptions.


        :param metadata_savers: The metadata_savers of this LibraryOptions.  # noqa: E501
        :type: list[str]
        """

        self._metadata_savers = metadata_savers

    @property
    def disabled_local_metadata_readers(self):
        """Gets the disabled_local_metadata_readers of this LibraryOptions.  # noqa: E501


        :return: The disabled_local_metadata_readers of this LibraryOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._disabled_local_metadata_readers

    @disabled_local_metadata_readers.setter
    def disabled_local_metadata_readers(self, disabled_local_metadata_readers):
        """Sets the disabled_local_metadata_readers of this LibraryOptions.


        :param disabled_local_metadata_readers: The disabled_local_metadata_readers of this LibraryOptions.  # noqa: E501
        :type: list[str]
        """

        self._disabled_local_metadata_readers = disabled_local_metadata_readers

    @property
    def local_metadata_reader_order(self):
        """Gets the local_metadata_reader_order of this LibraryOptions.  # noqa: E501


        :return: The local_metadata_reader_order of this LibraryOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._local_metadata_reader_order

    @local_metadata_reader_order.setter
    def local_metadata_reader_order(self, local_metadata_reader_order):
        """Sets the local_metadata_reader_order of this LibraryOptions.


        :param local_metadata_reader_order: The local_metadata_reader_order of this LibraryOptions.  # noqa: E501
        :type: list[str]
        """

        self._local_metadata_reader_order = local_metadata_reader_order

    @property
    def disabled_lyrics_fetchers(self):
        """Gets the disabled_lyrics_fetchers of this LibraryOptions.  # noqa: E501


        :return: The disabled_lyrics_fetchers of this LibraryOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._disabled_lyrics_fetchers

    @disabled_lyrics_fetchers.setter
    def disabled_lyrics_fetchers(self, disabled_lyrics_fetchers):
        """Sets the disabled_lyrics_fetchers of this LibraryOptions.


        :param disabled_lyrics_fetchers: The disabled_lyrics_fetchers of this LibraryOptions.  # noqa: E501
        :type: list[str]
        """

        self._disabled_lyrics_fetchers = disabled_lyrics_fetchers

    @property
    def save_lyrics_with_media(self):
        """Gets the save_lyrics_with_media of this LibraryOptions.  # noqa: E501


        :return: The save_lyrics_with_media of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._save_lyrics_with_media

    @save_lyrics_with_media.setter
    def save_lyrics_with_media(self, save_lyrics_with_media):
        """Sets the save_lyrics_with_media of this LibraryOptions.


        :param save_lyrics_with_media: The save_lyrics_with_media of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._save_lyrics_with_media = save_lyrics_with_media

    @property
    def lyrics_download_max_age_days(self):
        """Gets the lyrics_download_max_age_days of this LibraryOptions.  # noqa: E501


        :return: The lyrics_download_max_age_days of this LibraryOptions.  # noqa: E501
        :rtype: int
        """
        return self._lyrics_download_max_age_days

    @lyrics_download_max_age_days.setter
    def lyrics_download_max_age_days(self, lyrics_download_max_age_days):
        """Sets the lyrics_download_max_age_days of this LibraryOptions.


        :param lyrics_download_max_age_days: The lyrics_download_max_age_days of this LibraryOptions.  # noqa: E501
        :type: int
        """

        self._lyrics_download_max_age_days = lyrics_download_max_age_days

    @property
    def lyrics_fetcher_order(self):
        """Gets the lyrics_fetcher_order of this LibraryOptions.  # noqa: E501


        :return: The lyrics_fetcher_order of this LibraryOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._lyrics_fetcher_order

    @lyrics_fetcher_order.setter
    def lyrics_fetcher_order(self, lyrics_fetcher_order):
        """Sets the lyrics_fetcher_order of this LibraryOptions.


        :param lyrics_fetcher_order: The lyrics_fetcher_order of this LibraryOptions.  # noqa: E501
        :type: list[str]
        """

        self._lyrics_fetcher_order = lyrics_fetcher_order

    @property
    def lyrics_download_languages(self):
        """Gets the lyrics_download_languages of this LibraryOptions.  # noqa: E501


        :return: The lyrics_download_languages of this LibraryOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._lyrics_download_languages

    @lyrics_download_languages.setter
    def lyrics_download_languages(self, lyrics_download_languages):
        """Sets the lyrics_download_languages of this LibraryOptions.


        :param lyrics_download_languages: The lyrics_download_languages of this LibraryOptions.  # noqa: E501
        :type: list[str]
        """

        self._lyrics_download_languages = lyrics_download_languages

    @property
    def disabled_subtitle_fetchers(self):
        """Gets the disabled_subtitle_fetchers of this LibraryOptions.  # noqa: E501


        :return: The disabled_subtitle_fetchers of this LibraryOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._disabled_subtitle_fetchers

    @disabled_subtitle_fetchers.setter
    def disabled_subtitle_fetchers(self, disabled_subtitle_fetchers):
        """Sets the disabled_subtitle_fetchers of this LibraryOptions.


        :param disabled_subtitle_fetchers: The disabled_subtitle_fetchers of this LibraryOptions.  # noqa: E501
        :type: list[str]
        """

        self._disabled_subtitle_fetchers = disabled_subtitle_fetchers

    @property
    def subtitle_fetcher_order(self):
        """Gets the subtitle_fetcher_order of this LibraryOptions.  # noqa: E501


        :return: The subtitle_fetcher_order of this LibraryOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._subtitle_fetcher_order

    @subtitle_fetcher_order.setter
    def subtitle_fetcher_order(self, subtitle_fetcher_order):
        """Sets the subtitle_fetcher_order of this LibraryOptions.


        :param subtitle_fetcher_order: The subtitle_fetcher_order of this LibraryOptions.  # noqa: E501
        :type: list[str]
        """

        self._subtitle_fetcher_order = subtitle_fetcher_order

    @property
    def skip_subtitles_if_embedded_subtitles_present(self):
        """Gets the skip_subtitles_if_embedded_subtitles_present of this LibraryOptions.  # noqa: E501


        :return: The skip_subtitles_if_embedded_subtitles_present of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._skip_subtitles_if_embedded_subtitles_present

    @skip_subtitles_if_embedded_subtitles_present.setter
    def skip_subtitles_if_embedded_subtitles_present(self, skip_subtitles_if_embedded_subtitles_present):
        """Sets the skip_subtitles_if_embedded_subtitles_present of this LibraryOptions.


        :param skip_subtitles_if_embedded_subtitles_present: The skip_subtitles_if_embedded_subtitles_present of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._skip_subtitles_if_embedded_subtitles_present = skip_subtitles_if_embedded_subtitles_present

    @property
    def skip_subtitles_if_audio_track_matches(self):
        """Gets the skip_subtitles_if_audio_track_matches of this LibraryOptions.  # noqa: E501


        :return: The skip_subtitles_if_audio_track_matches of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._skip_subtitles_if_audio_track_matches

    @skip_subtitles_if_audio_track_matches.setter
    def skip_subtitles_if_audio_track_matches(self, skip_subtitles_if_audio_track_matches):
        """Sets the skip_subtitles_if_audio_track_matches of this LibraryOptions.


        :param skip_subtitles_if_audio_track_matches: The skip_subtitles_if_audio_track_matches of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._skip_subtitles_if_audio_track_matches = skip_subtitles_if_audio_track_matches

    @property
    def subtitle_download_languages(self):
        """Gets the subtitle_download_languages of this LibraryOptions.  # noqa: E501


        :return: The subtitle_download_languages of this LibraryOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._subtitle_download_languages

    @subtitle_download_languages.setter
    def subtitle_download_languages(self, subtitle_download_languages):
        """Sets the subtitle_download_languages of this LibraryOptions.


        :param subtitle_download_languages: The subtitle_download_languages of this LibraryOptions.  # noqa: E501
        :type: list[str]
        """

        self._subtitle_download_languages = subtitle_download_languages

    @property
    def subtitle_download_max_age_days(self):
        """Gets the subtitle_download_max_age_days of this LibraryOptions.  # noqa: E501


        :return: The subtitle_download_max_age_days of this LibraryOptions.  # noqa: E501
        :rtype: int
        """
        return self._subtitle_download_max_age_days

    @subtitle_download_max_age_days.setter
    def subtitle_download_max_age_days(self, subtitle_download_max_age_days):
        """Sets the subtitle_download_max_age_days of this LibraryOptions.


        :param subtitle_download_max_age_days: The subtitle_download_max_age_days of this LibraryOptions.  # noqa: E501
        :type: int
        """

        self._subtitle_download_max_age_days = subtitle_download_max_age_days

    @property
    def require_perfect_subtitle_match(self):
        """Gets the require_perfect_subtitle_match of this LibraryOptions.  # noqa: E501


        :return: The require_perfect_subtitle_match of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._require_perfect_subtitle_match

    @require_perfect_subtitle_match.setter
    def require_perfect_subtitle_match(self, require_perfect_subtitle_match):
        """Sets the require_perfect_subtitle_match of this LibraryOptions.


        :param require_perfect_subtitle_match: The require_perfect_subtitle_match of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._require_perfect_subtitle_match = require_perfect_subtitle_match

    @property
    def save_subtitles_with_media(self):
        """Gets the save_subtitles_with_media of this LibraryOptions.  # noqa: E501


        :return: The save_subtitles_with_media of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._save_subtitles_with_media

    @save_subtitles_with_media.setter
    def save_subtitles_with_media(self, save_subtitles_with_media):
        """Sets the save_subtitles_with_media of this LibraryOptions.


        :param save_subtitles_with_media: The save_subtitles_with_media of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._save_subtitles_with_media = save_subtitles_with_media

    @property
    def forced_subtitles_only(self):
        """Gets the forced_subtitles_only of this LibraryOptions.  # noqa: E501


        :return: The forced_subtitles_only of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._forced_subtitles_only

    @forced_subtitles_only.setter
    def forced_subtitles_only(self, forced_subtitles_only):
        """Sets the forced_subtitles_only of this LibraryOptions.


        :param forced_subtitles_only: The forced_subtitles_only of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._forced_subtitles_only = forced_subtitles_only

    @property
    def hearing_impaired_subtitles_only(self):
        """Gets the hearing_impaired_subtitles_only of this LibraryOptions.  # noqa: E501


        :return: The hearing_impaired_subtitles_only of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._hearing_impaired_subtitles_only

    @hearing_impaired_subtitles_only.setter
    def hearing_impaired_subtitles_only(self, hearing_impaired_subtitles_only):
        """Sets the hearing_impaired_subtitles_only of this LibraryOptions.


        :param hearing_impaired_subtitles_only: The hearing_impaired_subtitles_only of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._hearing_impaired_subtitles_only = hearing_impaired_subtitles_only

    @property
    def type_options(self):
        """Gets the type_options of this LibraryOptions.  # noqa: E501


        :return: The type_options of this LibraryOptions.  # noqa: E501
        :rtype: list[TypeOptions]
        """
        return self._type_options

    @type_options.setter
    def type_options(self, type_options):
        """Sets the type_options of this LibraryOptions.


        :param type_options: The type_options of this LibraryOptions.  # noqa: E501
        :type: list[TypeOptions]
        """

        self._type_options = type_options

    @property
    def collapse_single_item_folders(self):
        """Gets the collapse_single_item_folders of this LibraryOptions.  # noqa: E501


        :return: The collapse_single_item_folders of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._collapse_single_item_folders

    @collapse_single_item_folders.setter
    def collapse_single_item_folders(self, collapse_single_item_folders):
        """Sets the collapse_single_item_folders of this LibraryOptions.


        :param collapse_single_item_folders: The collapse_single_item_folders of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._collapse_single_item_folders = collapse_single_item_folders

    @property
    def enable_adult_metadata(self):
        """Gets the enable_adult_metadata of this LibraryOptions.  # noqa: E501


        :return: The enable_adult_metadata of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._enable_adult_metadata

    @enable_adult_metadata.setter
    def enable_adult_metadata(self, enable_adult_metadata):
        """Sets the enable_adult_metadata of this LibraryOptions.


        :param enable_adult_metadata: The enable_adult_metadata of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._enable_adult_metadata = enable_adult_metadata

    @property
    def import_collections(self):
        """Gets the import_collections of this LibraryOptions.  # noqa: E501


        :return: The import_collections of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._import_collections

    @import_collections.setter
    def import_collections(self, import_collections):
        """Sets the import_collections of this LibraryOptions.


        :param import_collections: The import_collections of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._import_collections = import_collections

    @property
    def disable_multi_version_items(self):
        """Gets the disable_multi_version_items of this LibraryOptions.  # noqa: E501


        :return: The disable_multi_version_items of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._disable_multi_version_items

    @disable_multi_version_items.setter
    def disable_multi_version_items(self, disable_multi_version_items):
        """Sets the disable_multi_version_items of this LibraryOptions.


        :param disable_multi_version_items: The disable_multi_version_items of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._disable_multi_version_items = disable_multi_version_items

    @property
    def disable_multi_part_items(self):
        """Gets the disable_multi_part_items of this LibraryOptions.  # noqa: E501


        :return: The disable_multi_part_items of this LibraryOptions.  # noqa: E501
        :rtype: bool
        """
        return self._disable_multi_part_items

    @disable_multi_part_items.setter
    def disable_multi_part_items(self, disable_multi_part_items):
        """Sets the disable_multi_part_items of this LibraryOptions.


        :param disable_multi_part_items: The disable_multi_part_items of this LibraryOptions.  # noqa: E501
        :type: bool
        """

        self._disable_multi_part_items = disable_multi_part_items

    @property
    def min_collection_items(self):
        """Gets the min_collection_items of this LibraryOptions.  # noqa: E501


        :return: The min_collection_items of this LibraryOptions.  # noqa: E501
        :rtype: int
        """
        return self._min_collection_items

    @min_collection_items.setter
    def min_collection_items(self, min_collection_items):
        """Sets the min_collection_items of this LibraryOptions.


        :param min_collection_items: The min_collection_items of this LibraryOptions.  # noqa: E501
        :type: int
        """

        self._min_collection_items = min_collection_items

    @property
    def music_folder_structure(self):
        """Gets the music_folder_structure of this LibraryOptions.  # noqa: E501


        :return: The music_folder_structure of this LibraryOptions.  # noqa: E501
        :rtype: str
        """
        return self._music_folder_structure

    @music_folder_structure.setter
    def music_folder_structure(self, music_folder_structure):
        """Sets the music_folder_structure of this LibraryOptions.


        :param music_folder_structure: The music_folder_structure of this LibraryOptions.  # noqa: E501
        :type: str
        """

        self._music_folder_structure = music_folder_structure

    @property
    def min_resume_pct(self):
        """Gets the min_resume_pct of this LibraryOptions.  # noqa: E501

        The minimum percentage of an item that must be played in order for playstate to be updated.  # noqa: E501

        :return: The min_resume_pct of this LibraryOptions.  # noqa: E501
        :rtype: int
        """
        return self._min_resume_pct

    @min_resume_pct.setter
    def min_resume_pct(self, min_resume_pct):
        """Sets the min_resume_pct of this LibraryOptions.

        The minimum percentage of an item that must be played in order for playstate to be updated.  # noqa: E501

        :param min_resume_pct: The min_resume_pct of this LibraryOptions.  # noqa: E501
        :type: int
        """

        self._min_resume_pct = min_resume_pct

    @property
    def max_resume_pct(self):
        """Gets the max_resume_pct of this LibraryOptions.  # noqa: E501

        The maximum percentage of an item that can be played while still saving playstate. If this percentage is crossed playstate will be reset to the beginning and the item will be marked watched.  # noqa: E501

        :return: The max_resume_pct of this LibraryOptions.  # noqa: E501
        :rtype: int
        """
        return self._max_resume_pct

    @max_resume_pct.setter
    def max_resume_pct(self, max_resume_pct):
        """Sets the max_resume_pct of this LibraryOptions.

        The maximum percentage of an item that can be played while still saving playstate. If this percentage is crossed playstate will be reset to the beginning and the item will be marked watched.  # noqa: E501

        :param max_resume_pct: The max_resume_pct of this LibraryOptions.  # noqa: E501
        :type: int
        """

        self._max_resume_pct = max_resume_pct

    @property
    def min_resume_duration_seconds(self):
        """Gets the min_resume_duration_seconds of this LibraryOptions.  # noqa: E501

        The minimum duration that an item must have in order to be eligible for playstate updates..  # noqa: E501

        :return: The min_resume_duration_seconds of this LibraryOptions.  # noqa: E501
        :rtype: int
        """
        return self._min_resume_duration_seconds

    @min_resume_duration_seconds.setter
    def min_resume_duration_seconds(self, min_resume_duration_seconds):
        """Sets the min_resume_duration_seconds of this LibraryOptions.

        The minimum duration that an item must have in order to be eligible for playstate updates..  # noqa: E501

        :param min_resume_duration_seconds: The min_resume_duration_seconds of this LibraryOptions.  # noqa: E501
        :type: int
        """

        self._min_resume_duration_seconds = min_resume_duration_seconds

    @property
    def thumbnail_images_interval_seconds(self):
        """Gets the thumbnail_images_interval_seconds of this LibraryOptions.  # noqa: E501


        :return: The thumbnail_images_interval_seconds of this LibraryOptions.  # noqa: E501
        :rtype: int
        """
        return self._thumbnail_images_interval_seconds

    @thumbnail_images_interval_seconds.setter
    def thumbnail_images_interval_seconds(self, thumbnail_images_interval_seconds):
        """Sets the thumbnail_images_interval_seconds of this LibraryOptions.


        :param thumbnail_images_interval_seconds: The thumbnail_images_interval_seconds of this LibraryOptions.  # noqa: E501
        :type: int
        """

        self._thumbnail_images_interval_seconds = thumbnail_images_interval_seconds

    @property
    def sample_ignore_size(self):
        """Gets the sample_ignore_size of this LibraryOptions.  # noqa: E501


        :return: The sample_ignore_size of this LibraryOptions.  # noqa: E501
        :rtype: int
        """
        return self._sample_ignore_size

    @sample_ignore_size.setter
    def sample_ignore_size(self, sample_ignore_size):
        """Sets the sample_ignore_size of this LibraryOptions.


        :param sample_ignore_size: The sample_ignore_size of this LibraryOptions.  # noqa: E501
        :type: int
        """

        self._sample_ignore_size = sample_ignore_size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LibraryOptions, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LibraryOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class ConfigurationToneMappingToneMapOptionsVisibility(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'show_advanced': 'bool',
        'is_software_tone_mapping_available': 'bool',
        'is_any_hardware_tone_mapping_available': 'bool',
        'show_nvidia_options': 'bool',
        'show_quick_sync_options': 'bool',
        'show_vaapi_options': 'bool',
        'is_open_cl_available': 'bool',
        'is_open_cl_super_t_available': 'bool',
        'is_vaapi_native_available': 'bool',
        'is_quick_sync_native_available': 'bool',
        'operating_system': 'OperatingSystem'
    }

    attribute_map = {
        'show_advanced': 'ShowAdvanced',
        'is_software_tone_mapping_available': 'IsSoftwareToneMappingAvailable',
        'is_any_hardware_tone_mapping_available': 'IsAnyHardwareToneMappingAvailable',
        'show_nvidia_options': 'ShowNvidiaOptions',
        'show_quick_sync_options': 'ShowQuickSyncOptions',
        'show_vaapi_options': 'ShowVaapiOptions',
        'is_open_cl_available': 'IsOpenClAvailable',
        'is_open_cl_super_t_available': 'IsOpenClSuperTAvailable',
        'is_vaapi_native_available': 'IsVaapiNativeAvailable',
        'is_quick_sync_native_available': 'IsQuickSyncNativeAvailable',
        'operating_system': 'OperatingSystem'
    }

    def __init__(self, show_advanced=None, is_software_tone_mapping_available=None, is_any_hardware_tone_mapping_available=None, show_nvidia_options=None, show_quick_sync_options=None, show_vaapi_options=None, is_open_cl_available=None, is_open_cl_super_t_available=None, is_vaapi_native_available=None, is_quick_sync_native_available=None, operating_system=None):  # noqa: E501
        """ConfigurationToneMappingToneMapOptionsVisibility - a model defined in Swagger"""  # noqa: E501
        self._show_advanced = None
        self._is_software_tone_mapping_available = None
        self._is_any_hardware_tone_mapping_available = None
        self._show_nvidia_options = None
        self._show_quick_sync_options = None
        self._show_vaapi_options = None
        self._is_open_cl_available = None
        self._is_open_cl_super_t_available = None
        self._is_vaapi_native_available = None
        self._is_quick_sync_native_available = None
        self._operating_system = None
        self.discriminator = None
        if show_advanced is not None:
            self.show_advanced = show_advanced
        if is_software_tone_mapping_available is not None:
            self.is_software_tone_mapping_available = is_software_tone_mapping_available
        if is_any_hardware_tone_mapping_available is not None:
            self.is_any_hardware_tone_mapping_available = is_any_hardware_tone_mapping_available
        if show_nvidia_options is not None:
            self.show_nvidia_options = show_nvidia_options
        if show_quick_sync_options is not None:
            self.show_quick_sync_options = show_quick_sync_options
        if show_vaapi_options is not None:
            self.show_vaapi_options = show_vaapi_options
        if is_open_cl_available is not None:
            self.is_open_cl_available = is_open_cl_available
        if is_open_cl_super_t_available is not None:
            self.is_open_cl_super_t_available = is_open_cl_super_t_available
        if is_vaapi_native_available is not None:
            self.is_vaapi_native_available = is_vaapi_native_available
        if is_quick_sync_native_available is not None:
            self.is_quick_sync_native_available = is_quick_sync_native_available
        if operating_system is not None:
            self.operating_system = operating_system

    @property
    def show_advanced(self):
        """Gets the show_advanced of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501


        :return: The show_advanced of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501
        :rtype: bool
        """
        return self._show_advanced

    @show_advanced.setter
    def show_advanced(self, show_advanced):
        """Sets the show_advanced of this ConfigurationToneMappingToneMapOptionsVisibility.


        :param show_advanced: The show_advanced of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501
        :type: bool
        """

        self._show_advanced = show_advanced

    @property
    def is_software_tone_mapping_available(self):
        """Gets the is_software_tone_mapping_available of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501


        :return: The is_software_tone_mapping_available of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501
        :rtype: bool
        """
        return self._is_software_tone_mapping_available

    @is_software_tone_mapping_available.setter
    def is_software_tone_mapping_available(self, is_software_tone_mapping_available):
        """Sets the is_software_tone_mapping_available of this ConfigurationToneMappingToneMapOptionsVisibility.


        :param is_software_tone_mapping_available: The is_software_tone_mapping_available of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501
        :type: bool
        """

        self._is_software_tone_mapping_available = is_software_tone_mapping_available

    @property
    def is_any_hardware_tone_mapping_available(self):
        """Gets the is_any_hardware_tone_mapping_available of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501


        :return: The is_any_hardware_tone_mapping_available of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501
        :rtype: bool
        """
        return self._is_any_hardware_tone_mapping_available

    @is_any_hardware_tone_mapping_available.setter
    def is_any_hardware_tone_mapping_available(self, is_any_hardware_tone_mapping_available):
        """Sets the is_any_hardware_tone_mapping_available of this ConfigurationToneMappingToneMapOptionsVisibility.


        :param is_any_hardware_tone_mapping_available: The is_any_hardware_tone_mapping_available of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501
        :type: bool
        """

        self._is_any_hardware_tone_mapping_available = is_any_hardware_tone_mapping_available

    @property
    def show_nvidia_options(self):
        """Gets the show_nvidia_options of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501


        :return: The show_nvidia_options of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501
        :rtype: bool
        """
        return self._show_nvidia_options

    @show_nvidia_options.setter
    def show_nvidia_options(self, show_nvidia_options):
        """Sets the show_nvidia_options of this ConfigurationToneMappingToneMapOptionsVisibility.


        :param show_nvidia_options: The show_nvidia_options of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501
        :type: bool
        """

        self._show_nvidia_options = show_nvidia_options

    @property
    def show_quick_sync_options(self):
        """Gets the show_quick_sync_options of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501


        :return: The show_quick_sync_options of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501
        :rtype: bool
        """
        return self._show_quick_sync_options

    @show_quick_sync_options.setter
    def show_quick_sync_options(self, show_quick_sync_options):
        """Sets the show_quick_sync_options of this ConfigurationToneMappingToneMapOptionsVisibility.


        :param show_quick_sync_options: The show_quick_sync_options of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501
        :type: bool
        """

        self._show_quick_sync_options = show_quick_sync_options

    @property
    def show_vaapi_options(self):
        """Gets the show_vaapi_options of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501


        :return: The show_vaapi_options of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501
        :rtype: bool
        """
        return self._show_vaapi_options

    @show_vaapi_options.setter
    def show_vaapi_options(self, show_vaapi_options):
        """Sets the show_vaapi_options of this ConfigurationToneMappingToneMapOptionsVisibility.


        :param show_vaapi_options: The show_vaapi_options of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501
        :type: bool
        """

        self._show_vaapi_options = show_vaapi_options

    @property
    def is_open_cl_available(self):
        """Gets the is_open_cl_available of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501


        :return: The is_open_cl_available of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501
        :rtype: bool
        """
        return self._is_open_cl_available

    @is_open_cl_available.setter
    def is_open_cl_available(self, is_open_cl_available):
        """Sets the is_open_cl_available of this ConfigurationToneMappingToneMapOptionsVisibility.


        :param is_open_cl_available: The is_open_cl_available of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501
        :type: bool
        """

        self._is_open_cl_available = is_open_cl_available

    @property
    def is_open_cl_super_t_available(self):
        """Gets the is_open_cl_super_t_available of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501


        :return: The is_open_cl_super_t_available of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501
        :rtype: bool
        """
        return self._is_open_cl_super_t_available

    @is_open_cl_super_t_available.setter
    def is_open_cl_super_t_available(self, is_open_cl_super_t_available):
        """Sets the is_open_cl_super_t_available of this ConfigurationToneMappingToneMapOptionsVisibility.


        :param is_open_cl_super_t_available: The is_open_cl_super_t_available of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501
        :type: bool
        """

        self._is_open_cl_super_t_available = is_open_cl_super_t_available

    @property
    def is_vaapi_native_available(self):
        """Gets the is_vaapi_native_available of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501


        :return: The is_vaapi_native_available of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501
        :rtype: bool
        """
        return self._is_vaapi_native_available

    @is_vaapi_native_available.setter
    def is_vaapi_native_available(self, is_vaapi_native_available):
        """Sets the is_vaapi_native_available of this ConfigurationToneMappingToneMapOptionsVisibility.


        :param is_vaapi_native_available: The is_vaapi_native_available of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501
        :type: bool
        """

        self._is_vaapi_native_available = is_vaapi_native_available

    @property
    def is_quick_sync_native_available(self):
        """Gets the is_quick_sync_native_available of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501


        :return: The is_quick_sync_native_available of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501
        :rtype: bool
        """
        return self._is_quick_sync_native_available

    @is_quick_sync_native_available.setter
    def is_quick_sync_native_available(self, is_quick_sync_native_available):
        """Sets the is_quick_sync_native_available of this ConfigurationToneMappingToneMapOptionsVisibility.


        :param is_quick_sync_native_available: The is_quick_sync_native_available of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501
        :type: bool
        """

        self._is_quick_sync_native_available = is_quick_sync_native_available

    @property
    def operating_system(self):
        """Gets the operating_system of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501


        :return: The operating_system of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501
        :rtype: OperatingSystem
        """
        return self._operating_system

    @operating_system.setter
    def operating_system(self, operating_system):
        """Sets the operating_system of this ConfigurationToneMappingToneMapOptionsVisibility.


        :param operating_system: The operating_system of this ConfigurationToneMappingToneMapOptionsVisibility.  # noqa: E501
        :type: OperatingSystem
        """

        self._operating_system = operating_system

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ConfigurationToneMappingToneMapOptionsVisibility, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConfigurationToneMappingToneMapOptionsVisibility):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
